Czech Core Metadata Model

Tento soubor dokumentuje Czech Core Metadata Model (@en).

## Přehled

View for Czech Core Metadata Model

## Profily tříd

#### Access rights (@en)

IRI profilovaných tříd | dcterms:RightsStatement
IRI | https://model.ccmm.cz/research-data/AccessRights
Název | Access rights (@en)
Definice | A statement about the access rights to the dataset. (@en)
Profiluje | profil Rights Statement (@en) (https://mff-uk.github.io/specifications/dcat-ap#RightsStatement) profil Rights Statement (@en) (https://mff-uk.github.io/specifications/dcat-dap#RightsStatement) třída Rights Statement (@en) (dcterms:RightsStatement) Definice: A statement about the intellectual property rights (IPR) held in or over a resource, a legal document giving official permission to do something with a resource, or a statement about access rights.
Popis použití v profilu | Use IRI identifier from the register http://purl.org/coar/access_right/. (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/AccessRights.label
Název | label (@en)
Definice | Label of the access rights vocabulary value. (@en)
Definiční obor | Access rights (@en)
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.
Popis použití v profilu | Short label of the value from register http://purl.org/coar/access_right/. Allowed English values are 'embargoes access', 'metadata only access', 'open access' and 'restricted access'. (@en)

#### Address (@en)

IRI profilovaných tříd | locn:Address
IRI | https://model.ccmm.cz/research-data/Address
Název | Address (@en)
Definice | A spatial object that in a human-readable way identifies a fixed location. (@en)
Profiluje | třída Address (@en) (locn:Address) Definice:
Popis použití v profilu | Address shall refer to the IRI identifier of an address from existing Address registry (e.g. RÚIAN for Czechia). In cases, where address identifier does not exist or cannot be used, fill address details using class attributes. (@en)

Zpětné asociace

- z domény →

#### address area (@en)

IRI profilovaných vztahů | locn:addressArea
IRI | https://model.ccmm.cz/research-data/Address.addressArea
Název | address area (@en)
Definice | The name of a geographic area that groups Addresses. (@en)
Definiční obor | Address (@en)
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost address area (@en) (locn:addressArea) Definice:
Popis použití v profilu | This would typically be part of a city, a neighbourhood or village, e.g. Montmartre. Address area is not an administrative unit. (@en)

#### administrative unit level 1 (@en)

IRI profilovaných vztahů | locn:adminUnitL1
IRI | https://model.ccmm.cz/research-data/Address.administrativeUnitLevel1
Název | administrative unit level 1 (@en)
Definice | The name of the uppermost level of the address, almost always a country. (@en)
Definiční obor | Address (@en)
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost admin unit level 1 (@en) (locn:adminUnitL1) Definice:
Popis použití v profilu | Best practice is to use the ISO 3166-1 code but if this is inappropriate for the context, country names should be provided in a consistent manner to reduce ambiguity. For example, either write 'France' or 'FRA' consistently throughout the dataset and avoid mixing the two. The Country controlled vocabulary from the Publications Office can be reused for this. (@en)

#### administrative unit level 2 (@en)

IRI profilovaných vztahů | locn:adminUnitL2
IRI | https://model.ccmm.cz/research-data/Address.administrativeUnitLevel2
Název | administrative unit level 2 (@en)
Definice | The name of a secondary level/region of the address, usually a county, state or other such area that typically encompasses several localities. (@en)
Definiční obor | Address (@en)
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost admin unit level 2 (@en) (locn:adminUnitL2) Definice:
Popis použití v profilu | Values could be a region or province, more granular than level 1. (@en)

#### full address (@en)

IRI profilovaných vztahů | locn:fullAddress
IRI | https://model.ccmm.cz/research-data/Address.fullAddress
Název | full address (@en)
Definice | The complete address written as a string. (@en)
Definiční obor | Address (@en)
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost full address (@en) (locn:fullAddress) Definice:
Popis použití v profilu | Use of this property is recommended as it will not suffer any misunderstandings that might arise through the breaking up of an address into its component parts. This property is analogous to vCard's label property but with two important differences: (1) formatting is not assumed so that, unlike vCard label, it may not be suitable to print this on an address label, (2) vCard's label property has a domain of vCard Address; the fullAddress property has no such restriction. An example of a full address is "Champ de Mars, 5 Avenue Anatole France, 75007 Paris, France". (@en)

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/Address.label
Název | label (@en)
Definice | Address label (@en)
Definiční obor | Address (@en) [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### locator designator (@en)

IRI profilovaných vztahů | locn:locatorDesignator
IRI | https://model.ccmm.cz/research-data/Address.locatorDesignator
Název | locator designator (@en)
Definice | A number or sequence of characters that uniquely identifies the locator within the relevant scope. (@en)
Definiční obor | Address (@en)
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost locator designator (@en) (locn:locatorDesignator) Definice:
Popis použití v profilu | In simpler terms, this is the building number, apartment number, etc. For an address such as "Flat 3, 17 Bridge Street", the locator is "flat 3, 17". (@en)

#### locator name (@en)

IRI profilovaných vztahů | locn:locatorName
IRI | https://model.ccmm.cz/research-data/Address.locatorName
Název | locator name (@en)
Definice | Proper noun(s) applied to the real world entity identified by the locator. The locator name could be the name of the property or complex, of the building or part of the building, or it could be the name of a room inside a building. (@en)
Definiční obor | Address (@en)
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost locator name (@en) (locn:locatorName) Definice:
Popis použití v profilu | The locator name could be the name of the property or complex, of the building or part of the building, or it could be the name of a room inside a building. The key difference between a locator designator and a locator name is that the latter is a proper name and is unlikely to include digits. For example, "Shumann, Berlaymont" is a meeting room within the European Commission headquarters for which locator name is more appropriate than locator. (@en)

#### post code (@en)

IRI profilovaných vztahů | locn:postCode
IRI | https://model.ccmm.cz/research-data/Address.postCode
Název | post code (@en)
Definice | The code created and maintained for postal purposes to identify a subdivision of addresses and postal delivery points. (@en)
Definiční obor | Address (@en)
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost post code (@en) (locn:postCode) Definice:
Popis použití v profilu | Post codes are common elements in many countries' postal address systems. One of the many post codes of Paris is for example "75000". (@en)

#### post name (@en)

IRI profilovaných vztahů | locn:postName
IRI | https://model.ccmm.cz/research-data/Address.postName
Název | post name (@en)
Definice | A name created and maintained for postal purposes to identify a subdivision of addresses and postal delivery points. (@en)
Definiční obor | Address (@en)
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost post name (@en) (locn:postName) Definice:
Popis použití v profilu | Usually a city, for example "Paris". Eventually name of the post itself. (@en)

#### post office box (@en)

IRI profilovaných vztahů | locn:poBox
IRI | https://model.ccmm.cz/research-data/Address.poBox
Název | post office box (@en)
Definice | A location designator for a postal delivery point at a post office, usually a number. (@en)
Definiční obor | Address (@en)
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost PO box (@en) (locn:poBox) Definice:

#### thoroughfare (@en)

IRI profilovaných vztahů | locn:thoroughfare
IRI | https://model.ccmm.cz/research-data/Address.thoroughfare
Název | thoroughfare (@en)
Definice | The name of a passage or way through from one location to another. (@en)
Definiční obor | Address (@en)
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost thoroughfare (@en) (locn:thoroughfare) Definice:
Popis použití v profilu | A thoroughfare is usually a street, but it might be a waterway or some other feature. For example, "Avenue des Champs-Élysées". (@en)

#### Agent (@en)

IRI profilovaných tříd | foaf:Agent
IRI | https://model.ccmm.cz/research-data/Agent
Název | Agent (@en)
Definice | Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources. (@en)
Profiluje | profil Agent (@en) (https://mff-uk.github.io/specifications/dcat-ap#Agent) Definice: Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources. profil Agent (@en) (https://mff-uk.github.io/specifications/dcat-dap#Agent) třída Agent (@en) (foaf:Agent) Definice: An agent (eg. person, group, software or physical artifact).

Zpětné asociace

- z domény →
- z domény →
- z domény →

#### has identifier (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier
IRI | https://model.ccmm.cz/research-data/Agent.hasIdentifier
Název | has identifier (@en)
Definice | has identifier (@en)
Definiční obor | Agent (@en)
Obor hodnot | Identifier (@en) [0..*]
Profiluje | vlastnost has identifier (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier) Definice: has identifier

#### má kontaktní bod

IRI profilovaných vztahů | dcat:contactPoint
IRI | https://model.ccmm.cz/research-data/Agent.contactPoint
Název | má kontaktní bod
Definice | Relevantní kontaktní informace pro katalogizovaný zdroj. Doporučuje se použít slovník VCard.
Definiční obor | Agent (@en)
Obor hodnot | Contact details (@en) [0..*]
Profiluje | vlastnost kontaktní bod (dcat:contactPoint) Definice: Relevantní kontaktní informace pro katalogizovaný zdroj. Doporučuje se použít slovník VCard.

#### name (@en)

IRI profilovaných vztahů | foaf:name
IRI | https://model.ccmm.cz/research-data/Agent.name
Název | name (@en)
Definice | Name of the agent. (@en)
Definiční obor | Agent (@en)
Obor hodnot | xsd:string [1..1]
Profiluje | vlastnost name (@en) (foaf:name) Definice: A name for some thing.
Popis použití v profilu | It is used for the official name of the agent. For Persons it is combination of first and family names. Recommended format is "family names, first names". (@en)

#### Alternate title (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/ccmm#AlternateTitle
IRI | https://model.ccmm.cz/research-data/AlternateTitle
Název | Alternate title (@en)
Definice | Alternate title of the resource. (@en)
Profiluje | třída Alternate title (@en) (https://model.ccmm.cz/vocabulary/ccmm#AlternateTitle) Definice: Alternate title of the resource.

Zpětné asociace

- z domény →

#### has alternate title type (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasType
IRI | https://model.ccmm.cz/research-data/AlternateTitle.hasType
Název | has alternate title type (@en)
Definice | Type of the alternate name relation. (@en)
Definiční obor | Alternate title (@en)
Obor hodnot | Alternate title type (@en) [0..1]
Profiluje | vlastnost has type (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasType) Definice: Reference to the codelist value giving the specific type to the attribute.
Popis použití v profilu | References to the value from https://vocabs.ccmm.cz/registry/codelist/AlternateTitle/. (@en)

#### title (@en)

IRI profilovaných vztahů | dcterms:title
IRI | https://model.ccmm.cz/research-data/AlternateTitle.title
Název | title (@en)
Definice | A human-readable name for the subject. (@en)
Definiční obor | Alternate title (@en) [0..*]
Obor hodnot | rdf:langString [1..*]
Profiluje | vlastnost Title (@en) (dcterms:title) Definice: A name given to the resource.

#### Alternate title type (@en)

IRI profilovaných tříd | skos:Concept
IRI | https://model.ccmm.cz/research-data/AlternateTitleType
Název | Alternate title type (@en)
Definice | Type of alternate title. (@en)
Profiluje | třída Concept (@en) (skos:Concept) Definice: An idea or notion; a unit of thought.
Popis použití v profilu | Use value from codelist https://vocabs.ccmm.cz/registry/codelist/AlternateTitle/. (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/AlternateTitleType.label
Název | label (@en)
Definice | Alternate title type label. (@en)
Definiční obor | Alternate title type (@en)
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.
Popis použití v profilu | Use label of a respective value from https://vocabs.ccmm.cz/registry/codelist/AlternateTitle/. (@en)

#### Application profile (@en)

IRI profilovaných tříd | dcterms:Standard
IRI | https://model.ccmm.cz/research-data/ApplicationProfile
Název | Application profile (@en)
Definice | A standard or other specification to which a metadata record conforms. (@en)
Profiluje | profil Standard (@en) (https://mff-uk.github.io/specifications/dcat-ap#Standard) Definice: A standard or other specification to which a resource conforms. profil Standard (@en) (https://mff-uk.github.io/specifications/dcat-dap#Standard) třída Standard (@en) (dcterms:Standard) Definice: A reference point against which other things can be evaluated or compared.

Zpětné asociace

- z domény →
- z domény →
- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/ApplicationProfile.label
Název | label (@en)
Definice | Label of application profile (@en)
Definiční obor | Application profile (@en) [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### Checksum (@en)

IRI profilovaných tříd | spdx:Checksum
IRI | https://model.ccmm.cz/research-data/Checksum
Název | Checksum (@en)
Definice | A value that allows the contents of a file to be authenticated. (@en)
Profiluje | profil Checksum (@en) (https://mff-uk.github.io/specifications/dcat-ap#Checksum) Definice: A value that allows the contents of a file to be authenticated. profil Checksum (@en) (https://mff-uk.github.io/specifications/dcat-dap#Checksum) třída beze jména (spdx:Checksum) Definice: A Checksum is value that allows the contents of a file to be authenticated. Even small changes to the content of the file will change its checksum. This class allows the results of a variety of checksum and cryptographic message digest algorithms to be represented.
Popis použití v profilu | This class allows the results of a variety of checksum and cryptographic message digest algorithms to be represented. (@en)

Zpětné asociace

- z domény →

#### checksum value (@en)

IRI profilovaných vztahů | spdx:checksumValue
IRI | https://model.ccmm.cz/research-data/Checksum.checksumValue
Název | checksum value (@en)
Definice | A lower case hexadecimal encoded digest value produced using a specific algorithm. (@en)
Definiční obor | Checksum (@en) [0..*]
Obor hodnot | xsd:hexBinary [1..1]
Profiluje | profil checksum value (@en) (https://mff-uk.github.io/specifications/dcat-ap#Checksum.checksumValue) Definice: A lower case hexadecimal encoded digest value produced using a specific algorithm. profil checksum value (@en) (https://mff-uk.github.io/specifications/dcat-dap#Checksum.checksumValue) vlastnost beze jména (spdx:checksumValue) Definice: The checksumValue property provides a lower case hexidecimal encoded digest value produced using a specific algorithm.
Popis použití v profilu | Value is generated automatically using given algorithm. (@en)

#### uses algorithm (@en)

IRI profilovaných vztahů | spdx:algorithm
IRI | https://model.ccmm.cz/research-data/Checksum.usesAlgorithm
Název | uses algorithm (@en)
Definice | The algorithm used to produce the subject Checksum. (@en)
Definiční obor | Checksum (@en)
Obor hodnot | Checksum algorithm (@en) [1..1]
Profiluje | profil algorithm (@en) (https://mff-uk.github.io/specifications/dcat-ap#Checksum.algorithm) Definice: The algorithm used to produce the subject Checksum. profil algorithm (@en) (https://mff-uk.github.io/specifications/dcat-dap#Checksum.algorithm) Definice: Identifies the algorithm used to produce the subject Checksum [SPDX]. vlastnost beze jména (spdx:algorithm) Definice: Identifies the algorithm used to produce the subject Checksum. Currently, SHA-1 is the only supported algorithm. It is anticipated that other algorithms will be supported at a later time.
Popis použití v profilu | Version 2.2 of [SPDX] defines individuals for the following algorithms: MD2, MD4, MD5, MD6, SHA-1, SHA-224, SHA-256, SHA-384, SHA-512. (@en)

#### Checksum algorithm (@en)

IRI profilovaných tříd | spdx:ChecksumAlgorithm
IRI | https://model.ccmm.cz/research-data/ChecksumAlgorithm
Název | Checksum algorithm (@en)
Definice | Algorithm used for Checksums. (@en)
Profiluje | profil Checksum Algorithm (@en) (https://mff-uk.github.io/specifications/dcat-ap#ChecksumAlgorithm) profil Checksum Algorithm (@en) (https://mff-uk.github.io/specifications/dcat-dap#ChecksumAlgorithm) třída beze jména (spdx:ChecksumAlgorithm) Definice: Algorighm for Checksums.

Zpětné asociace

- z domény →

#### Contact details (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/ccmm#ContactDetails
IRI | https://model.ccmm.cz/research-data/ContactDetails
Název | Contact details (@en)
Definice | Details to contact the agent in a relationship to the resource. (@en)
Profiluje | třída Contact details (@en) (https://model.ccmm.cz/vocabulary/ccmm#ContactDetails) Definice: Contact details such as telephone, e-mail address etc.
Popis použití v profilu | Describes contact details, such as telephone, e--mail address etc. (@en)

Zpětné asociace

- z domény →

#### data box (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#dataBox
IRI | https://model.ccmm.cz/research-data/ContactDetails.dataBox
Název | data box (@en)
Definice | Code of the data box. (@en)
Definiční obor | Contact details (@en) [0..*]
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost Data box (@en) (https://model.ccmm.cz/vocabulary/ccmm#dataBox) Definice: Data box code
Popis použití v profilu | (@en)

#### email (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#email
IRI | https://model.ccmm.cz/research-data/ContactDetails.email
Název | email (@en)
Definice | Email address. (@en)
Definiční obor | Contact details (@en) [0..*]
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost Email (@en) (https://model.ccmm.cz/vocabulary/ccmm#email) Definice: Email address
Popis použití v profilu | Email address in standard format, e.g. john.doe@domain.com (@en)

#### has address (@en)

IRI profilovaných vztahů | vcard:hasAddress
IRI | https://model.ccmm.cz/research-data/ContactDetails.hasAddress
Název | has address (@en)
Definice | To specify the components of the delivery address for the object (@en)
Definiční obor | Contact details (@en)
Obor hodnot | Address (@en) [0..*]
Profiluje | vlastnost has address (@en) (vcard:hasAddress) Definice: To specify the components of the delivery address for the object
Popis použití v profilu | Either links to IRI of address in address registry or describes the address using Address class attributes. (@en)

#### phone (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#phone
IRI | https://model.ccmm.cz/research-data/ContactDetails.phone
Název | phone (@en)
Definice | Phone number (@en)
Definiční obor | Contact details (@en) [0..*]
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost Phone (@en) (https://model.ccmm.cz/vocabulary/ccmm#phone) Definice: Phone number
Popis použití v profilu | Phone number in international format +xx(x) xxx xxx xxx (@en)

#### Data service (@en)

IRI profilovaných tříd | dcat:DataService
IRI | https://model.ccmm.cz/research-data/DataService
Název | Data service (@en)
Definice | Umístění či přístupový bod poskytující operace související s hledáním, přistupem k, či výkonem funkcí na datech či souvisejících zdrojích.
Profiluje | profil Data service (@en) (https://mff-uk.github.io/specifications/dcat-ap#DataService) profil Data service (@en) (https://mff-uk.github.io/specifications/dcat-dap#DataService) Definice: Umístění či přístupový bod poskytující operace související s hledáním, přistupem k, či výkonem funkcí na datech či souvisejících zdrojích. třída Data service (@en) (dcat:DataService) Definice: Umístění či přístupový bod poskytující operace související s hledáním, přistupem k, či výkonem funkcí na datech či souvisejících zdrojích.

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/DataService.label
Název | label (@en)
Definice | Data service label (@en)
Definiční obor | Data service (@en) [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### přístupový bod služby

IRI profilovaných vztahů | dcat:endpointURL
IRI | https://model.ccmm.cz/research-data/DataService.endpointUrl
Název | přístupový bod služby
Definice | Kořenové umístění nebo hlavní přístupový bod služby (IRI přístupné přes Web).
Definiční obor | Data service (@en)
Obor hodnot | Resource (@en) [1..*]
Profiluje | profil přístupový bod služby (https://mff-uk.github.io/specifications/dcat-ap#DataService.endpointUrl) Definice: Kořenové umístění nebo hlavní přístupový bod služby (IRI přístupné přes Web). profil přístupový bod služby (https://mff-uk.github.io/specifications/dcat-dap#DataService.endpointUrl) vlastnost přístupový bod služby (dcat:endpointURL) Definice: Kořenové umístění nebo hlavní přístupový bod služby (IRI přístupné přes Web).

#### Date type (@en)

IRI profilovaných tříd | skos:Concept
IRI | https://model.ccmm.cz/research-data/DateType
Název | Date type (@en)
Definice | Type of a date in relation to the resource. (@en)
Profiluje | třída Concept (@en) (skos:Concept) Definice: An idea or notion; a unit of thought.
Popis použití v profilu | Use value from codelist https://vocabs.ccmm.cz/registry/codelist/TimeReference/. (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/DateType.label
Název | label (@en)
Definice | Date type label. (@en)
Definiční obor | Date type (@en)
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### Datová sada

IRI profilovaných tříd | dcat:Dataset
IRI | https://model.ccmm.cz/research-data/Dataset
Název | Datová sada
Definice | Kolekce dat poskytovaná či řízená jedním zdrojem, která je k dispozici pro přístup či stažení v jednom či více formátech.
Profiluje | třída Datová sada (dcat:Dataset) Definice: Kolekce dat poskytovaná či řízená jedním zdrojem, která je k dispozici pro přístup či stažení v jednom či více formátech.

Zpětné asociace

- z domény →

#### has alternate title (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasAlternateTitle
IRI | https://model.ccmm.cz/research-data/Dataset.hasAlternateTitle
Název | has alternate title (@en)
Definiční obor | Datová sada
Obor hodnot | Alternate title (@en) [0..*]
Profiluje | vlastnost has alternate title (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasAlternateTitle) Definice:

#### has description (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#hasDescription
IRI | https://model.ccmm.cz/research-data/Dataset.hasDescription
Název | has description (@en)
Definice | Relation to the description of a dataset. (@en)
Definiční obor | Datová sada
Obor hodnot | Description (@en) [0..*]
Profiluje | vlastnost has description (@en) (https://model.ccmm.cz/vocabulary/datacite#hasDescription) Definice:
Popis použití v profilu | Description may have various type from the codelist https://vocabs.ccmm.cz/registry/codelist/DescriptionType/. (@en)

#### has distribution (@en)

IRI profilovaných vztahů | dcat:distribution
IRI | https://model.ccmm.cz/research-data/Dataset.hasDistribution
Název | has distribution (@en)
Definice | Dostupná distribuce datové sady.
Definiční obor | Datová sada
Obor hodnot | Distribuce [0..*]
Profiluje | profil distribuce (https://mff-uk.github.io/specifications/dcat-ap#Dataset.datasetDistribution) Definice: Dostupná distribuce datové sady. profil distribuce (https://mff-uk.github.io/specifications/dcat-dap#Dataset.distribution) vlastnost distribuce (dcat:distribution) Definice: Dostupná distribuce datové sady.
Popis použití v profilu | For the distribution of data in the form of files use instances of class Distribution – downloadable file. For the distribution of data through service use instance of class Distribution – data service. (@en)

#### has funding reference (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#hasFundingReference
IRI | https://model.ccmm.cz/research-data/Dataset.hasFundingReference
Název | has funding reference (@en)
Definice | Has reference for funding of a dataset acquisition. (@en)
Definiční obor | Datová sada
Obor hodnot | Funding reference (@en) [0..*]
Profiluje | vlastnost has funding reference (@en) (https://model.ccmm.cz/vocabulary/datacite#hasFundingReference) Definice:

#### has identifier (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier
IRI | https://model.ccmm.cz/research-data/Dataset.hasIdentifier
Název | has identifier (@en)
Definice | has identifier (@en)
Definiční obor | Datová sada
Obor hodnot | Identifier (@en) [1..*]
Profiluje | vlastnost has identifier (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier) Definice: has identifier

#### has location (@en)

IRI profilovaných vztahů | dcterms:spatial
IRI | https://model.ccmm.cz/research-data/Dataset.hasLocation
Název | has location (@en)
Definice | The geographical area covered by the dataset. (@en)
Definiční obor | Datová sada
Obor hodnot | Location (@en) [0..*]
Profiluje | profil geographical coverage (@en) (https://mff-uk.github.io/specifications/dcat-ap#Dataset.geographicalCoverage) profil spatial/geographical coverage (@en) (https://mff-uk.github.io/specifications/dcat-dap#Dataset.spatial-geographicalCoverage) Definice: The geographical area covered by the dataset. vlastnost Spatial Coverage (@en) (dcterms:spatial) Definice: Spatial characteristics of the resource.
Popis použití v profilu | In the CCMM spatial coverage does not only cover the area of dataset, it may be connected to the dataset in some other way, e.g. the place from where the data were measured, administrative area to which the dataset conforms or other. (@en)

#### has other language (@en)

IRI profilovaných vztahů | dcterms:language
IRI | https://model.ccmm.cz/research-data/Dataset.hasOtherLanguage
Název | has other language (@en)
Definice | Any other languages of the Dataset. (@en)
Definiční obor | Datová sada
Obor hodnot | Language system (@en) [0..*]
Profiluje | profil language (@en) (https://mff-uk.github.io/specifications/dcat-ap#Dataset.language) Definice: A language of the Dataset. profil language (@en) (https://mff-uk.github.io/specifications/dcat-dap#CataloguedResource.language) Definice: A language of the resource. This refers to the natural language used for textual metadata (i.e., titles, descriptions, etc.) of a cataloged resource (i.e., dataset or service) or the textual values of a dataset distribution vlastnost Language (@en) (dcterms:language) Definice: A language of the resource.
Popis použití v profilu | This property can be repeated if there are multiple languages in the Dataset. (@en)

#### has primary language (@en)

IRI profilovaných vztahů | dcterms:language
IRI | https://model.ccmm.cz/research-data/Dataset.hasPrimaryLanguage
Název | has primary language (@en)
Definice | A primary language of the Dataset. (@en)
Definiční obor | Datová sada
Obor hodnot | Language system (@en) [0..1]
Profiluje | profil language (@en) (https://mff-uk.github.io/specifications/dcat-ap#Dataset.language) Definice: A language of the Dataset. profil language (@en) (https://mff-uk.github.io/specifications/dcat-dap#CataloguedResource.language) Definice: A language of the resource. This refers to the natural language used for textual metadata (i.e., titles, descriptions, etc.) of a cataloged resource (i.e., dataset or service) or the textual values of a dataset distribution vlastnost Language (@en) (dcterms:language) Definice: A language of the resource.

#### has provenance (@en)

IRI profilovaných vztahů | dcterms:provenance
IRI | https://model.ccmm.cz/research-data/Dataset.hasProvenance
Název | has provenance (@en)
Definice | A statement about the lineage of a Dataset. (@en)
Definiční obor | Datová sada
Obor hodnot | Provenance Statement (@en) [0..*]
Profiluje | profil provenance (@en) (https://mff-uk.github.io/specifications/dcat-ap#Dataset.provenance) Definice: A statement about the lineage of a Dataset. vlastnost Provenance (@en) (dcterms:provenance) Definice: A statement of any changes in ownership and custody of the resource since its creation that are significant for its authenticity, integrity, and interpretation.

#### has related resource (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasRelatedResource
IRI | https://model.ccmm.cz/research-data/Dataset.hasRelatedResource
Název | has related resource (@en)
Definice | Reference to the resource in any way related to the described dataset. (@en)
Definiční obor | Datová sada
Obor hodnot | Resource (@en) [0..*]
Profiluje | vlastnost has related resource (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasRelatedResource) Definice:

#### has resource type (@en)

IRI profilovaných vztahů | dcterms:type
IRI | https://model.ccmm.cz/research-data/Dataset.resourceType
Název | has resource type (@en)
Definice | A resource type of the Dataset. (@en)
Definiční obor | Datová sada
Obor hodnot | Resource type (@en) [0..1]
Profiluje | profil type (@en) (https://mff-uk.github.io/specifications/dcat-ap#Dataset.type) Definice: A type of the Dataset. profil type/genre (@en) (https://mff-uk.github.io/specifications/dcat-dap#CataloguedResource.type-genre) vlastnost Type (@en) (dcterms:type) Definice: The nature or genre of the resource.
Popis použití v profilu | Use IRI identifier of a value from the register https://vocabularies.coar-repositories.org/resource_types/. (@en)

#### has subject (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#hasSubject
IRI | https://model.ccmm.cz/research-data/Dataset.hasSubject
Název | has subject (@en)
Definice | Dataset described using a subject. (@en)
Definiční obor | Datová sada
Obor hodnot | Subject (@en) [1..*]
Profiluje | vlastnost has subject (@en) (https://model.ccmm.cz/vocabulary/datacite#hasSubject) Definice:
Popis použití v profilu | At least one subject must be a value from FRASCATI FORD vocabulary. For that subject use reference codelist https://vocabs.ccmm.cz/registry/codelist/SubjectCategory/ as the Subject scheme and select at least one value from this codelist as a subject. (@en)

#### has terms of use (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#hasVersion
IRI | https://model.ccmm.cz/research-data/Dataset.hasTermsOfUse
Název | has terms of use (@en)
Definice | Terms under which the dataset may be accessed. (@en)
Definiční obor | Datová sada
Obor hodnot | Terms of use (@en) [1..1]
Profiluje | vlastnost has version (@en) (https://model.ccmm.cz/vocabulary/datacite#hasVersion) Definice:

#### has time reference (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasTimeReference
IRI | https://model.ccmm.cz/research-data/Dataset.hasTimeReference
Název | has time reference (@en)
Definice | Reference to events related to the dataset. (@en)
Definiční obor | Datová sada
Obor hodnot | Time reference (@en) [1..*]
Profiluje | vlastnost has time reference (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasTimeReference) Definice:
Popis použití v profilu | Must contain at least one time reference with date type value "Created" from https://vocabs.ccmm.cz/registry/codelist/TimeReference/. (@en)

#### has validation result (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasValidationResult
IRI | https://model.ccmm.cz/research-data/Dataset.hasValidationResult
Název | has validation result (@en)
Definice | Reference to the report about the dataset validation. (@en)
Definiční obor | Datová sada
Obor hodnot | Validation result (@en) [0..*]
Profiluje | vlastnost has validation result (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasValidationResult) Definice:

#### is described by (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#isDescribedBy
IRI | https://model.ccmm.cz/research-data/Dataset.isDescribedBy
Název | is described by (@en)
Definice | Inverse relation between dataset and metadata record. (@en)
Definiční obor | Datová sada
Obor hodnot | Katalogizační záznam [1..*]
Profiluje | vlastnost is described by (@en) (https://model.ccmm.cz/vocabulary/ccmm#isDescribedBy) Definice: Inverse relation between dataset and metadata record.

#### publication year (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#relatedItemPublicationYear
IRI | https://model.ccmm.cz/research-data/Dataset.publicationYear
Název | publication year (@en)
Definice | The year when the item was or will be made publicly available. (@en)
Definiční obor | Datová sada [0..*]
Obor hodnot | xsd:gYear [1..1]
Profiluje | vlastnost publication year (@en) (https://model.ccmm.cz/vocabulary/datacite#relatedItemPublicationYear) Definice: The year when the item was or will be made publicly available.
Popis použití v profilu | If TimeReference with dateType "Issued" is present, year in that date and publicationYear must be the same“ (@en)

#### qualified relation (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#qualifiedRelation
IRI | https://model.ccmm.cz/research-data/Dataset.qualifiedRelation
Název | qualified relation (@en)
Definice | Link to a description of a relationship between dataset and an agent with the specification of the role of agent in this relationship. (@en)
Definiční obor | Datová sada
Obor hodnot | Resource to agent relationship (@en) [1..*]
Profiluje | vlastnost qualified relation (@en) (https://model.ccmm.cz/vocabulary/ccmm#qualifiedRelation) Definice:
Popis použití v profilu | Description of relationship between dataset and agent (e.g. creator, publisher, etc.). Role in a relationship is given by the Resource agent role type. Use a value from vocabulary https://vocabs.ccmm.cz/registry/codelist/AgentRole/. Each dataset shall have at least two qualified relations: one with role "Creator" and second with role "Publisher". If metadata manager is the same for dataset and metadata, it shall also have at least one qualified relation with role "data manager". (@en)

#### title (@en)

IRI profilovaných vztahů | dcterms:title
IRI | https://model.ccmm.cz/research-data/Dataset.title
Název | title (@en)
Definice | A name given to the dataset. (@en)
Definiční obor | Datová sada [1..1]
Obor hodnot | xsd:string [1..1]
Profiluje | vlastnost Title (@en) (dcterms:title) Definice: A name given to the resource.

#### version (@en)

IRI profilovaných vztahů | dcat:version
IRI | https://model.ccmm.cz/research-data/Dataset.version
Název | version (@en)
Definice | The version indicator (name or identifier) of a resource. (@en)
Definiční obor | Datová sada [0..*]
Obor hodnot | xsd:string [0..1]
Profiluje | profil version (@en) (https://mff-uk.github.io/specifications/dcat-ap#Dataset.version) profil version (@en) (https://mff-uk.github.io/specifications/dcat-dap#CataloguedResource.version) vlastnost version (@en) (dcat:version) Definice: The version indicator (name or identifier) of a resource.

#### Description (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/datacite#Description
IRI | https://model.ccmm.cz/research-data/Description
Název | Description (@en)
Definice | All additional information that does not fit in any of the other categories. May be used for technical information or detailed information associated with a scientific instrument. (@en)
Profiluje | třída Description (@en) (https://model.ccmm.cz/vocabulary/datacite#Description) Definice: All additional information that does not fit in any of the other categories. May be used for technical information or detailed information associated with a scientific instrument.
Popis použití v profilu | Description of the resource may have also a description type. (@en)

Zpětné asociace

- z domény →

#### description text (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#descriptionText
IRI | https://model.ccmm.cz/research-data/Description.descriptionText
Název | description text (@en)
Definice | Text describing the resource. (@en)
Definiční obor | Description (@en) [0..*]
Obor hodnot | xsd:string [1..1]
Profiluje | vlastnost description text (@en) (https://model.ccmm.cz/vocabulary/datacite#descriptionText) Definice: Text describing the resource.

#### has description type (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#hasDescriptionType
IRI | https://model.ccmm.cz/research-data/Description.hasDescriptionType
Název | has description type (@en)
Definice | Relation to the type of the description. (@en)
Definiční obor | Description (@en)
Obor hodnot | Description type (@en) [0..1]
Profiluje | vlastnost has description type (@en) (https://model.ccmm.cz/vocabulary/datacite#hasDescriptionType) Definice: Relation to the type of the description.
Popis použití v profilu | Type of the description from the codelist https://vocabs.ccmm.cz/registry/codelist/DescriptionType/. (@en)

#### Description type (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/datacite#DescriptionType
IRI | https://model.ccmm.cz/research-data/DescriptionType
Název | Description type (@en)
Definice | The type of the description. (@en)
Profiluje | třída Description type (@en) (https://model.ccmm.cz/vocabulary/datacite#DescriptionType) Definice: The type of the description.
Popis použití v profilu | Use value from codelist https://vocabs.ccmm.cz/registry/codelist/DescriptionType/. (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/DescriptionType.label
Název | label (@en)
Definice | Label of the description type. (@en)
Definiční obor | Description type (@en)
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### Distribuce

IRI profilovaných tříd | dcat:Distribution
IRI | https://model.ccmm.cz/research-data/Distribution
Název | Distribuce
Definice | Konkrétní reprezentace datové sady. Datová sada může být dostupná v různých serializacích, které se mohou navzájem lišit různými způsoby, mimo jiné přirozeným jazykem, media-typem či formátem, schematickou organizací, časovým a prostorovým rozlišením, úrovní detailu či profily (které mohou specifikovat některé či všechny tyto rozdíly).
Profiluje | profil Distribuce (https://mff-uk.github.io/specifications/dcat-ap#Distribution) profil Distribuce (https://mff-uk.github.io/specifications/dcat-dap#Distribution) třída Distribuce (dcat:Distribution) Definice: Konkrétní reprezentace datové sady. Datová sada může být dostupná v různých serializacích, které se mohou navzájem lišit různými způsoby, mimo jiné přirozeným jazykem, media-typem či formátem, schematickou organizací, časovým a prostorovým rozlišením, úrovní detailu či profily (které mohou specifikovat některé či všechny tyto rozdíly).
Popis použití v profilu | This represents a general availability of a dataset. It implies no information about the actual access method of the data, i.e., whether by direct download, API, or through a Web page. This is an abstract type. Use its subclasses to determine downloadable file or data service. (@en)

Zpětné asociace

- z domény →

#### title (@en)

IRI profilovaných vztahů |
IRI | https://model.ccmm.cz/research-data/Distribution.title
Název | title (@en)
Definiční obor | Distribuce [0..*]
Obor hodnot | rdf:langString [1..1]

#### Distribution - data service (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/ccmm#Distribution-DataService
IRI | https://model.ccmm.cz/research-data/Distribution-DataService
Název | Distribution - data service (@en)
Definice | Physical embodiment of the dataset distribution as a particular data service. (@en)
Profiluje | třída Distribution - data service (@en) (https://model.ccmm.cz/vocabulary/ccmm#Distribution-DataService) Definice: Physical embodiment of the dataset as a particular data service.

#### conforms to specification (@en)

IRI profilovaných vztahů | dcterms:conformsTo
IRI | https://model.ccmm.cz/research-data/Distribution-DataService.conformsToSpecification
Název | conforms to specification (@en)
Definice | An established standard to which the distribution conforms. (@en)
Definiční obor | Distribution - data service (@en)
Obor hodnot | Application profile (@en) [0..*]
Profiluje | profil linked schemas (@en) (https://mff-uk.github.io/specifications/dcat-ap#Distribution.linkedSchemas) profil conforms to (@en) (https://mff-uk.github.io/specifications/dcat-dap#Distribution.conformsTo) Definice: An established standard to which the distribution conforms. vlastnost Conforms To (@en) (dcterms:conformsTo) Definice: An established standard to which the described resource conforms.
Popis použití v profilu | This property SHOULD be used to indicate the profile or specification that this data service conforms to. This is (generally) a complementary concern to the service standard. (@en)

#### description (@en)

IRI profilovaných vztahů |
IRI | https://model.ccmm.cz/research-data/Distribution-DataService.Description
Název | description (@en)
Definice | A free-text account of the Distribution. (@en)
Definiční obor | Distribution - data service (@en) [0..*]
Obor hodnot | Text [0..*]
Popis použití v profilu | This property can be repeated for parallel language versions of the description. (@en)

#### has documentation (@en)

IRI profilovaných vztahů | foaf:page
IRI | https://model.ccmm.cz/research-data/Distribution-DataService.hasDocumentation
Název | has documentation (@en)
Definice | A page or document about this Distribution. (@en)
Definiční obor | Distribution - data service (@en)
Obor hodnot | Documentation (@en) [0..*]
Profiluje | profil documentation (@en) (https://mff-uk.github.io/specifications/dcat-ap#Distribution.documentation) Definice: A page or document about this Distribution. vlastnost page (@en) (foaf:page) Definice: A page or document about this thing.

#### služba pro přístup k datům

IRI profilovaných vztahů | dcat:accessService
IRI | https://model.ccmm.cz/research-data/Distribution-DataService.hasAccessService
Název | služba pro přístup k datům
Definice | Umístění či přístupový bod zpřístupňující distribuci datové sady.
Definiční obor | Distribution - data service (@en)
Obor hodnot | Data service (@en) [0..*]
Profiluje | profil služba pro přístup k datům (https://mff-uk.github.io/specifications/dcat-ap#Distribution.accessService) profil služba pro přístup k datům (https://mff-uk.github.io/specifications/dcat-dap#Distribution.accessService) vlastnost služba pro přístup k datům (dcat:accessService) Definice: Umístění či přístupový bod zpřístupňující distribuci datové sady.
Popis použití v profilu | Access service SHOULD be used to link to a description of Data service that can provide access to this distribution. (@en)

#### Distribution - downloadable file (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/ccmm#Distribution-DownloadableFile
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile
Název | Distribution - downloadable file (@en)
Definice | Physical embodiment of the dataset in a particular format. (@en)
Profiluje | třída Distribution - downloadable file (@en) (https://model.ccmm.cz/vocabulary/ccmm#Distribution-DownloadableFile) Definice: Physical embodiment of the dataset in a particular format.

#### byte size (@en)

IRI profilovaných vztahů | dcat:byteSize
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.byteSize
Název | byte size (@en)
Definice | The size of a Distribution in bytes. (@en)
Definiční obor | Distribution - downloadable file (@en) [0..*]
Obor hodnot | xsd:integer [1..1]
Profiluje | profil velikost v bajtech (https://mff-uk.github.io/specifications/dcat-ap#Distribution.byteSize) profil velikost v bajtech (https://mff-uk.github.io/specifications/dcat-dap#Distribution.byteSize) vlastnost velikost v bajtech (dcat:byteSize) Definice: Velikost distribuce v bajtech.

#### conforms to schema (@en)

IRI profilovaných vztahů | dcterms:conformsTo
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.conformsToSchema
Název | conforms to schema (@en)
Definice | An established standard to which the distribution conforms. (@en)
Definiční obor | Distribution - downloadable file (@en)
Obor hodnot | Application profile (@en) [0..*]
Profiluje | profil linked schemas (@en) (https://mff-uk.github.io/specifications/dcat-ap#Distribution.linkedSchemas) profil conforms to (@en) (https://mff-uk.github.io/specifications/dcat-dap#Distribution.conformsTo) Definice: An established standard to which the distribution conforms. vlastnost Conforms To (@en) (dcterms:conformsTo) Definice: An established standard to which the described resource conforms.
Popis použití v profilu | This property SHOULD be used to indicate the model, schema, ontology, view or profile that this representation of a dataset conforms to. This is (generally) a complementary concern to the media-type or format. (@en)

#### has checksum (@en)

IRI profilovaných vztahů | spdx:checksum
IRI | https://model.ccmm.cz/research-data/Distribution-DataService.hasChecksum
Název | has checksum (@en)
Definice | A mechanism that can be used to verify that the contents of a distribution have not changed. (@en)
Definiční obor | Distribution - downloadable file (@en)
Obor hodnot | Checksum (@en) [0..1]
Profiluje | profil checksum (@en) (https://mff-uk.github.io/specifications/dcat-ap#Distribution.checksum) Definice: A mechanism that can be used to verify that the contents of a distribution have not changed. profil checksum (@en) (https://mff-uk.github.io/specifications/dcat-dap#Distribution.checksum) vlastnost beze jména (spdx:checksum) Definice: The checksum property provides a mechanism that can be used to verify that the contents of a File or Package have not changed.
Popis použití v profilu | The checksum is related to the download URL. (@en)

#### has format (@en)

IRI profilovaných vztahů | dcterms:format
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.hasFormat
Název | has format (@en)
Definice | The file format of the distribution. (@en)
Definiční obor | Distribution - downloadable file (@en)
Obor hodnot | Format (@en) [1..1]
Profiluje | profil format (@en) (https://mff-uk.github.io/specifications/dcat-ap#Distribution.format) profil format (@en) (https://mff-uk.github.io/specifications/dcat-dap#Distribution.format) Definice: The file format of the distribution. vlastnost Format (@en) (dcterms:format) Definice: The file format, physical medium, or dimensions of the resource.
Popis použití v profilu | (@en)

#### přístupová adresa

IRI profilovaných vztahů | dcat:accessURL
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.accessUrl
Název | přístupová adresa
Definice | URL zdroje, přes které je přístupná distribuce datové sady. Příkladem může být vstupní stránka, RSS kanál či SPARQL endpoint. Použijte ve všech případech kromě URL souboru ke stažení, pro které je lepší použít dcat:downloadURL.
Definiční obor | Distribution - downloadable file (@en)
Obor hodnot | File (@en) [1..*]
Profiluje | profil přístupová adresa (https://mff-uk.github.io/specifications/dcat-ap#Distribution.accessUrl) Definice: URL zdroje, přes které je přístupná distribuce datové sady. Příkladem může být vstupní stránka, RSS kanál či SPARQL endpoint. Použijte ve všech případech kromě URL souboru ke stažení, pro které je lepší použít dcat:downloadURL. profil přístupová adresa (https://mff-uk.github.io/specifications/dcat-dap#Distribution.accessUrl) Definice: URL zdroje, přes které je přístupná distribuce datové sady. Příkladem může být vstupní stránka, RSS kanál či SPARQL endpoint. Použijte ve všech případech kromě URL souboru ke stažení, pro které je lepší použít dcat:downloadURL. vlastnost přístupová adresa (dcat:accessURL) Definice: URL zdroje, přes které je přístupná distribuce datové sady. Příkladem může být vstupní stránka, RSS kanál či SPARQL endpoint. Použijte ve všech případech kromě URL souboru ke stažení, pro které je lepší použít dcat:downloadURL.
Popis použití v profilu | The resource at the access URL contains information about how to get the Dataset. It shall be the web page (not a document file). (@en)

#### typ média

IRI profilovaných vztahů | dcat:mediaType
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.mediaType
Název | typ média
Definice | Typ média distribuce definovaný v IANA.
Definiční obor | Distribution - downloadable file (@en)
Obor hodnot | Media Type (@en) [0..1]
Profiluje | profil typ média (https://mff-uk.github.io/specifications/dcat-ap#Distribution.mediaType) profil typ média (https://mff-uk.github.io/specifications/dcat-dap#Distribution.mediaType) vlastnost typ média (dcat:mediaType) Definice: Typ média distribuce definovaný v IANA.
Popis použití v profilu | This property SHOULD be used when the media type of the distribution is defined in IANA (using value from https://www.iana.org/assignments/media-types/media-types.xhtml), otherwise Format MAY be used with values from Publication Office of the EU File type codelist http://publications.europa.eu/resource/dataset/file-type. (@en)

#### URL souboru ke stažení

IRI profilovaných vztahů | dcat:downloadURL
IRI | https://model.ccmm.cz/research-data/Distribution-DownloadableFile.downloadUrl
Název | URL souboru ke stažení
Definice | URL souboru ke stažení v daném formátu, například CSV nebo RDF soubor. Formát je popsán vlastností distribuce dcterms:format a/nebo dcat:mediaType.
Definiční obor | Distribution - downloadable file (@en)
Obor hodnot | File (@en) [0..*]
Profiluje | profil URL souboru ke stažení (https://mff-uk.github.io/specifications/dcat-ap#Distribution.downloadUrl) Definice: URL souboru ke stažení v daném formátu, například CSV nebo RDF soubor. Formát je popsán vlastností distribuce dcterms:format a/nebo dcat:mediaType. profil URL souboru ke stažení (https://mff-uk.github.io/specifications/dcat-dap#Distribution.downloadUrl) vlastnost URL souboru ke stažení (dcat:downloadURL) Definice: URL souboru ke stažení v daném formátu, například CSV nebo RDF soubor. Formát je popsán vlastností distribuce dcterms:format a/nebo dcat:mediaType.
Popis použití v profilu | Download URL SHOULD be used for the URL at which this distribution is available directly, typically through a HTTP Get request. (@en)

#### Documentation (@en)

IRI profilovaných tříd | foaf:Document
IRI | https://model.ccmm.cz/research-data/Documentation
Název | Documentation (@en)
Definice | A textual resource intended for human consumption that contains information about the data service. (@en)
Profiluje | profil Document (@en) (https://mff-uk.github.io/specifications/dcat-ap#Document) Definice: A textual resource intended for human consumption that contains information, e.g. a web page about a Dataset. třída Document (@en) (foaf:Document) Definice: A document.

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/Documentation.label
Název | label (@en)
Definice | Documentation label (@en)
Definiční obor | Documentation (@en) [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### File (@en)

IRI profilovaných tříd | rdfs:Resource
IRI | https://model.ccmm.cz/research-data/File
Název | File (@en)
Definice | Digital resource representing collection of data. (@en)
Profiluje | profil Resource (@en) (https://mff-uk.github.io/specifications/dcat-ap#rdfs-Resource) Definice: Anything described by RDF. profil Resource (@en) (https://mff-uk.github.io/specifications/dcat-dap#rdfs-Resource) třída Resource (@en) (rdfs:Resource) Definice: The class resource, everything.
Popis použití v profilu | File is represented by URL on which is it accessable. (@en)

Zpětné asociace

- z domény →
- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/File.label
Název | label (@en)
Definice | File label (@en)
Definiční obor | File (@en) [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### Format (@en)

IRI profilovaných tříd | dcterms:MediaTypeOrExtent
IRI | https://model.ccmm.cz/research-data/Format
Název | Format (@en)
Definice | Format of downloadable file. (@en)
Profiluje | profil Media Type or Extent (@en) (https://mff-uk.github.io/specifications/dcat-ap#MediaTypeOrExtent) profil Media Type or Extent (@en) (https://mff-uk.github.io/specifications/dcat-dap#MediaTypeOrExtent) třída Media Type or Extent (@en) (dcterms:MediaTypeOrExtent) Definice: A media type or extent.
Popis použití v profilu | Use IRI identifier from the register http://publications.europa.eu/resource/dataset/file-type. Human readable codelist representation is here: https://op.europa.eu/en/web/eu-vocabularies/concept-scheme/-/resource?uri=http://publications.europa.eu/resource/authority/file-type. (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/Format.label
Název | label (@en)
Definice | Label of format value. (@en)
Definiční obor | Format (@en)
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.
Popis použití v profilu | Use a label of a codelist value from http://publications.europa.eu/resource/dataset/file-type. (@en)

#### Funding reference (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/datacite#FundingReference
IRI | https://model.ccmm.cz/research-data/FundingReference
Název | Funding reference (@en)
Definice | Information about financial support (funding) for the resource being registered. (@en)
Profiluje | třída Funding reference (@en) (https://model.ccmm.cz/vocabulary/datacite#FundingReference) Definice: Information about financial support (funding) for the resource being registered.

Zpětné asociace

- z domény →

#### award title (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#awardTitle
IRI | https://model.ccmm.cz/research-data/FundingReference.awardTitle
Název | award title (@en)
Definice | The human readable title or name of the award (grant). (@en)
Definiční obor | Funding reference (@en) [1..1]
Obor hodnot | xsd:string [0..1]
Profiluje | vlastnost award title (@en) (https://model.ccmm.cz/vocabulary/datacite#awardTitle) Definice: The human readable title or name of the award (grant).

#### funding program (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#fundingProgram
IRI | https://model.ccmm.cz/research-data/FundingReference.fundingProgram
Název | funding program (@en)
Definice | Reference to the specific funding program. (@en)
Definiční obor | Funding reference (@en) [0..*]
Obor hodnot | xsd:anyURI [0..1]
Profiluje | vlastnost Funding program (@en) (https://model.ccmm.cz/vocabulary/ccmm#fundingProgram) Definice: Reference to the specific funding program.

#### has funder (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#hasFunderIdentifier
IRI | https://model.ccmm.cz/research-data/FundingReference.hasFunder
Název | has funder (@en)
Definice | Relation to the agent entity of a funder. (@en)
Definiční obor | Funding reference (@en)
Obor hodnot | Agent (@en) [1..*]
Profiluje | vlastnost has funder identifier (@en) (https://model.ccmm.cz/vocabulary/datacite#hasFunderIdentifier) Definice:

#### local identifier (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#awardNumber
IRI | https://model.ccmm.cz/research-data/FundingReference.localIdentifier
Název | local identifier (@en)
Definice | The code assigned by the funder to a sponsored award (grant). (@en)
Definiční obor | Funding reference (@en) [0..*]
Obor hodnot | xsd:string [0..1]
Profiluje | vlastnost award number (@en) (https://model.ccmm.cz/vocabulary/datacite#awardNumber) Definice: The code assigned by the funder to a sponsored award (grant).
Popis použití v profilu | In case the award or grant has an ID or DOI, the full URL shall be included. (@en)

#### Geometry (@en)

IRI profilovaných tříd | locn:Geometry
IRI | https://model.ccmm.cz/research-data/Geometry
Název | Geometry (@en)
Definice | The Geometry class provides the means to identify a location as a point, line, polygon, etc. expressed using coordinates in some coordinate reference system. (@en)
Profiluje | profil Geometry (@en) (https://mff-uk.github.io/specifications/dcat-ap#Geometry) profil Geometry (@en) (https://mff-uk.github.io/specifications/dcat-dap#Geometry) třída Geometry (@en) (locn:Geometry) Definice:

Zpětné asociace

- z domény →

#### geography markup language literal (@en)

IRI profilovaných vztahů | http://www.opengis.net/ont/geosparql#asGML
IRI | https://model.ccmm.cz/research-data/Geometry.geographyMarkupLanguageLiteral
Název | geography markup language literal (@en)
Definice | Representation of geometry object as GML Literal. (@en)
Definiční obor | Geometry (@en)
Obor hodnot | http://www.opengis.net/ont/geosparql#gmlLiteral [0..*]
Profiluje | vlastnost gml (@en) (http://www.opengis.net/ont/geosparql#asGML) Definice:

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/Geometry.label
Název | label (@en)
Definice | Label of geometry object. (@en)
Definiční obor | Geometry (@en) [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### well known text literal (@en)

IRI profilovaných vztahů | http://www.opengis.net/ont/geosparql#asWKT
IRI | https://model.ccmm.cz/research-data/Geometry.wellKnownTextLiteral
Název | well known text literal (@en)
Definice | Representation of geometry object as WKT Literal. (@en)
Definiční obor | Geometry (@en)
Obor hodnot | http://www.opengis.net/ont/geosparql#wktLiteral [0..*]
Profiluje | vlastnost wkt (@en) (http://www.opengis.net/ont/geosparql#asWKT) Definice:

#### Identifier (@en)

IRI profilovaných tříd | adms:Identifier
IRI | https://model.ccmm.cz/research-data/Identifier
Název | Identifier (@en)
Definice | Unique and resolvable identifier containing the notation and identifier scheme in the form of URI. (@en)
Profiluje | třída Identifier (@en) (adms:Identifier) Definice: This class is based on the UN/CEFACT Identifier complex type defined in See Section 5.8 of Core Components Data Type Catalogue Version 3.1 (http://www.unece.org/fileadmin/DAM/cefact/codesfortrade/CCTS/CCTS-DTCatalogueVersion3p1.pdf) In RDF this is expressed using the following properties: - the content string should be provided using skos:notation, datatyped with the identifier scheme (inclduing the version number if appropriate); - use dcterms:creator to link to a class describing the agency that manages the identifier scheme or adms:schemaAgency to provide the name as a literal. Although not part of the ADMS conceptual model, it may be useful to provide further properties to the Identifier class such as dcterms:created to provide the date on which the identifier was issued.

Zpětné asociace

- z domény →
- z domény →
- z domény →

#### in scheme (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#inScheme
IRI | https://model.ccmm.cz/research-data/Identifier.inScheme
Název | in scheme (@en)
Definice | Relation between the identifier and scheme in which it is defined and unique. (@en)
Definiční obor | Identifier (@en)
Obor hodnot | Identifier scheme (@en) [1..1]
Profiluje | vlastnost in scheme (@en) (https://model.ccmm.cz/vocabulary/ccmm#inScheme) Definice: Relation between the identifier and scheme in which it is defined and unique.

#### value (@en)

IRI profilovaných vztahů | skos:notation
IRI | https://model.ccmm.cz/research-data/Identifier.value
Název | value (@en)
Definice | Value of the identifer within the given identifier scheme. (@en)
Definiční obor | Identifier (@en) [0..*]
Obor hodnot | xsd:string [1..1]
Profiluje | vlastnost notation (@en) (skos:notation) Definice: A notation, also known as classification code, is a string of characters such as "T58.5" or "303.4833" used to uniquely identify a concept within the scope of a given concept scheme.

#### Identifier scheme (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/ccmm#IdentifierScheme
IRI | https://model.ccmm.cz/research-data/IdentifierScheme
Název | Identifier scheme (@en)
Definice | Scheme in which is the identifier value unique, usually representing some authority. Identifier scheme shall always be represented as IRI identifier. (@en)
Profiluje | třída Identifier scheme (@en) (https://model.ccmm.cz/vocabulary/ccmm#IdentifierScheme) Definice: Scheme in which is the identifier value unique, usually representing some authority. Identifier scheme shall always be represented as IRI identifier.
Popis použití v profilu | Use identifier scheme in the form of IRI identifier. Methodology shall list known sources. (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/IdentifierScheme.label
Název | label (@en)
Definice | Identifier scheme label (@en)
Definiční obor | Identifier scheme (@en)
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.
Popis použití v profilu | E.g. DOI, ORCID etc... (@en)

#### Katalog

IRI profilovaných tříd | dcat:Catalog
IRI | https://model.ccmm.cz/research-data/Repository
Název | Katalog
Definice | Řízená kolekce metadat o datových sadách a datových službách
Profiluje | profil Katalog (https://mff-uk.github.io/specifications/dcat-ap#Catalogue) Definice: Řízená kolekce metadat o datových sadách a datových službách profil Katalog (https://mff-uk.github.io/specifications/dcat-dap#Catalog) Definice: Řízená kolekce metadat o datových sadách a datových službách třída Katalog (dcat:Catalog) Definice: Řízená kolekce metadat o datových sadách a datových službách

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/Repository.label
Název | label (@en)
Definice | Human readable name of the repository. (@en)
Definiční obor | Katalog [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### Katalogizační záznam

IRI profilovaných tříd | dcat:CatalogRecord
IRI | https://model.ccmm.cz/research-data/MetadataRecord
Název | Katalogizační záznam
Definice | Záznam v datovém katalogu popisující jednu datovou sadu či datovou službu.
Profiluje | profil Katalogizační záznam (https://mff-uk.github.io/specifications/dcat-ap#CatalogueRecord) profil Katalogizační záznam (https://mff-uk.github.io/specifications/dcat-dap#CatalogRecord) Definice: Záznam v datovém katalogu popisující jednu datovou sadu či datovou službu. třída Katalogizační záznam (dcat:CatalogRecord) Definice: Záznam v datovém katalogu popisující jednu datovou sadu či datovou službu.
Popis použití v profilu | In case metadata is harvested from external catalogue, metadata record IRI shall be the same as IRI of the metadata record in original repository. (@en)

Zpětné asociace

- z domény →

#### conforms to standard (@en)

IRI profilovaných vztahů | dcterms:conformsTo
IRI | https://model.ccmm.cz/research-data/MetadataRecord.conformsToStandard
Název | conforms to standard (@en)
Definice | An established standard to which the metadata record conforms. (@en)
Definiční obor | Katalogizační záznam
Obor hodnot | Application profile (@en) [0..*]
Profiluje | profil conforms to (@en) (https://mff-uk.github.io/specifications/dcat-dap#CatalogRecord.conformsTo) vlastnost Conforms To (@en) (dcterms:conformsTo) Definice: An established standard to which the described resource conforms.
Popis použití v profilu | This property SHOULD be used to indicate the standard or profile that was used to describe cataloged resource content. (@en)

#### date created (@en)

IRI profilovaných vztahů | dcterms:created
IRI | https://model.ccmm.cz/research-data/MetadataRecord.dateCreated
Název | date created (@en)
Definice | The date on which the metadata record was created. (@en)
Definiční obor | Katalogizační záznam [0..*]
Obor hodnot | xsd:date [0..1]
Profiluje | vlastnost Date Created (@en) (dcterms:created) Definice: Date of creation of the resource.

#### date updated (@en)

IRI profilovaných vztahů | dcterms:modified
IRI | https://model.ccmm.cz/research-data/MetadataRecord.dateUpdated
Název | date updated (@en)
Definice | Date on which the resource was changed. (@en)
Definiční obor | Katalogizační záznam [0..*]
Obor hodnot | xsd:date [0..*]
Profiluje | vlastnost Date Modified (@en) (dcterms:modified) Definice: Date on which the resource was changed.
Popis použití v profilu | The date on which the metadata record was changed or modified. (@en)

#### describes (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#describes
IRI | https://model.ccmm.cz/research-data/MetadataRecord.describes
Název | describes (@en)
Definice | Dataset described by the metadata record. (@en)
Definiční obor | Katalogizační záznam
Obor hodnot | Datová sada [0..*]
Profiluje | vlastnost describes (@en) (https://model.ccmm.cz/vocabulary/ccmm#describes) Definice: Dataset described by the metadata record.

#### has original repository (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#originalRepository
IRI | https://model.ccmm.cz/research-data/MetadataRecord.hasOriginalRepository
Název | has original repository (@en)
Definice | Link to the repository in which the metadata were originally stored and curated. (@en)
Definiční obor | Katalogizační záznam
Obor hodnot | Katalog [0..*]
Profiluje | vlastnost original repository (@en) (https://model.ccmm.cz/vocabulary/ccmm#originalRepository) Definice: Link to the repository from which the metadata were originally stored and curated.

#### kvalifikovaný vztah

IRI profilovaných vztahů |
IRI | https://model.ccmm.cz/research-data/MetadataRecord.qualifiedRelation
Název | kvalifikovaný vztah
Definice | Odkaz na popis vztahu s jiným zdrojem.
Definiční obor | Katalogizační záznam
Obor hodnot | Resource to agent relationship (@en) [1..*]
Popis použití v profilu | Relationship shall contain at least one agent with role "Data Manager" from codelist https://vocabs.ccmm.cz/registry/codelist/AgentRole/. (@en)

#### language (@en)

IRI profilovaných vztahů | dcterms:language
IRI | https://model.ccmm.cz/research-data/MetadataRecord.hasLanguage
Název | language (@en)
Definice | A language used in the textual metadata describing titles, descriptions of the metadata record. (@en)
Definiční obor | Katalogizační záznam
Obor hodnot | Language system (@en) [0..*]
Profiluje | profil language (@en) (https://mff-uk.github.io/specifications/dcat-ap#CatalogueRecord.language) Definice: A language used in the textual metadata describing titles, descriptions, etc. of the Catalogued Resource. vlastnost Language (@en) (dcterms:language) Definice: A language of the resource.
Popis použití v profilu | This property can be repeated if the metadata is provided in multiple languages. (@en)

#### Language system (@en)

IRI profilovaných tříd | dcterms:LinguisticSystem
IRI | https://model.ccmm.cz/research-data/LanguageSystem
Název | Language system (@en)
Definice | A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language. (@en)
Profiluje | profil Linguistic System (@en) (https://mff-uk.github.io/specifications/dcat-ap#LinguisticSystem) Definice: A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language. profil Linguistic System (@en) (https://mff-uk.github.io/specifications/dcat-dap#LinguisticSystem) třída Linguistic System (@en) (dcterms:LinguisticSystem) Definice: A system of signs, symbols, sounds, gestures, or rules used in communication.
Popis použití v profilu | Use IRI identifier from the register http://publications.europa.eu/resource/authority/language. (@en)

Zpětné asociace

- z domény →
- z domény →
- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/LanguageSystem.label
Název | label (@en)
Definice | Language label (@en)
Definiční obor | Language system (@en)
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.
Popis použití v profilu | Use language label and/or its 3-letter code from http://publications.europa.eu/resource/authority/language/. (@en)

#### License Document (@en)

IRI profilovaných tříd |
IRI | https://model.ccmm.cz/research-data/LicenseDocument
Název | License Document (@en)
Definice | A legal document giving official permission to do something with a resource. (@en)
Popis použití v profilu | (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/LicenseDocument.label
Název | label (@en)
Definice | Label of the license document. (@en)
Definiční obor | License Document (@en)
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### Location (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/datacite#Geolocation dcterms:Location
IRI | https://model.ccmm.cz/research-data/Location
Název | Location (@en)
Definice | Spatial region, named place or geometry representation of a place related to the dataset. (@en)
Profiluje | třída GeoLocation (@en) (https://model.ccmm.cz/vocabulary/datacite#Geolocation) Definice: Spatial region or named place where the data was gathered or about which the data is focused. profil Location (@en) (https://mff-uk.github.io/specifications/dcat-ap#Location) profil Location (@en) (https://mff-uk.github.io/specifications/dcat-dap#Location) třída Location (@en) (dcterms:Location) Definice: A spatial region or named place.
Popis použití v profilu | Location is represented according to the Open Formal Standard for Spatial Data. Locations are represented as a reference to the named place, geographic region or specific geometry according to the standardized geometry object representation. Every Location instance must have at least one of the following attributes/relations: bbox, location name, geometry and/or related object identifier. (@en)

Zpětné asociace

- z domény →

#### bounding box (@en)

IRI profilovaných vztahů | dcat:bbox
IRI | https://model.ccmm.cz/research-data/Location.bbox
Název | bounding box (@en)
Definice | Bounding box of the location geometry. (@en)
Definiční obor | Location (@en) [0..*]
Obor hodnot | Literal (@en) [0..*]
Profiluje | vlastnost ohraničení oblasti (dcat:bbox) Definice: Ohraničení geografické oblasti zdroje.
Popis použití v profilu | Typically defined by top-left and bottom-right corners. (@en)

#### has geometry (@en)

IRI profilovaných vztahů | locn:geometry
IRI | https://model.ccmm.cz/research-data/Location.hasGeometry
Název | has geometry (@en)
Definice | The corresponding geometry for a resource. (@en)
Definiční obor | Location (@en)
Obor hodnot | Geometry (@en) [0..1]
Profiluje | profil geometry (@en) (https://mff-uk.github.io/specifications/dcat-ap#Location.geometry) Definice: The corresponding geometry for a resource. profil geometry (@en) (https://mff-uk.github.io/specifications/dcat-dap#Location.geometry) Definice: Associates a spatial thing [SDW-BP] with a corresponding geometry. vlastnost geometry (@en) (locn:geometry) Definice: Associates any resource with the corresponding geometry.
Popis použití v profilu | The range of this property allows for any type of geometry specification. E.g., the geometry could be encoded by a literal, as WKT (geosparql:wktLiteral), or represented by a class, as geosparql:Geometry (or any of its subclasses). (@en)

#### has location relation type (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasType
IRI | https://model.ccmm.cz/research-data/Location.hasLocationRelationType
Název | has location relation type (@en)
Definice | Relation of the location to the dataset. (@en)
Definiční obor | Location (@en)
Obor hodnot | Location relation type (@en) [1..1]
Profiluje | vlastnost has type (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasType) Definice: Reference to the codelist value giving the specific type to the attribute.
Popis použití v profilu | Use values from codelist https://vocabs.ccmm.cz/registry/codelist/LocationRelation/. (@en)

#### has related object (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasRelatedResource
IRI | https://model.ccmm.cz/research-data/Location.hasRelatedObject
Název | has related object (@en)
Definice | Relation to the spatial object. (@en)
Definiční obor | Location (@en)
Obor hodnot | Resource (@en) [0..*]
Profiluje | vlastnost has related resource (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasRelatedResource) Definice:
Popis použití v profilu | The relation is provided by the identifier of the related object. It shall be identifier of an existing spatial object in a registry, such as Place Named Authority List (http://publications.europa.eu/resource/authority/place), Register of Territorial Identification, Addresses and Real Estates or others. (@en)

#### name (@en)

IRI profilovaných vztahů | dcterms:title
IRI | https://model.ccmm.cz/research-data/Location.name
Název | name (@en)
Definice | Name of the spatial location. (@en)
Definiční obor | Location (@en) [0..*]
Obor hodnot | Text [0..*]
Profiluje | vlastnost Title (@en) (dcterms:title) Definice: A name given to the resource.
Popis použití v profilu | Name of the place. Examples: Prague Castle, Tour d'Eiffel, Šumava National Park (@en)

#### Location relation type (@en)

IRI profilovaných tříd | skos:Concept
IRI | https://model.ccmm.cz/research-data/LocationRelationType
Název | Location relation type (@en)
Definice | Relation of the dataset to the resource. (@en)
Profiluje | třída Concept (@en) (skos:Concept) Definice: An idea or notion; a unit of thought.
Popis použití v profilu | Use value from codelist https://vocabs.ccmm.cz/registry/codelist/LocationRelation/. (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/LocationRelationType.label
Název | label (@en)
Definice | Label of location relation type. (@en)
Definiční obor | Location relation type (@en)
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### Media Type (@en)

IRI profilovaných tříd | dcterms:MediaType
IRI | https://model.ccmm.cz/research-data/MediaType
Název | Media Type (@en)
Definice | A file format. (@en)
Profiluje | profil Media Type (@en) (https://mff-uk.github.io/specifications/dcat-ap#MediaType) profil Media Type (@en) (https://mff-uk.github.io/specifications/dcat-dap#MediaType) třída Media Type (@en) (dcterms:MediaType) Definice: A file format or physical medium.
Popis použití v profilu | Use IRI value from registry https://www.iana.org/assignments/media-types/media-types.xhtml. (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/MediaType.label
Název | label (@en)
Definice | Media type label. (@en)
Definiční obor | Media Type (@en) [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### Organization (@en)

IRI profilovaných tříd | prov:Organization foaf:Agent
IRI | https://model.ccmm.cz/research-data/Organization
Název | Organization (@en)
Definice | Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. (@en)
Profiluje | třída Organization (@en) (prov:Organization) Definice: profil Agent (@en) (https://mff-uk.github.io/specifications/dcat-ap#Agent) Definice: Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources. profil Agent (@en) (https://mff-uk.github.io/specifications/dcat-dap#Agent) třída Agent (@en) (foaf:Agent) Definice: An agent (eg. person, group, software or physical artifact).

Zpětné asociace

- z domény →

#### alternate name (@en)

IRI profilovaných vztahů | vcard:organization-name
IRI | https://model.ccmm.cz/research-data/Organization.alternateName
Název | alternate name (@en)
Definice | To specify the organizational name associated with the object (@en)
Definiční obor | Organization (@en) [0..*]
Obor hodnot | Text [0..*]
Profiluje | vlastnost organization name (@en) (vcard:organization-name) Definice: To specify the organizational name associated with the object

#### Person (@en)

IRI profilovaných tříd | prov:Person
IRI | https://model.ccmm.cz/research-data/Person
Název | Person (@en)
Definice | Physical person. (@en)
Profiluje | třída Person (@en) (prov:Person) Definice:
Popis použití v profilu | (@en)

#### family name (@en)

IRI profilovaných vztahů | vcard:family-name
IRI | https://model.ccmm.cz/research-data/Person.familyName
Název | family name (@en)
Definice | The family name associated with the person. (@en)
Definiční obor | Person (@en) [0..*]
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost family name (@en) (vcard:family-name) Definice: The family name associated with the object

#### given name (@en)

IRI profilovaných vztahů | vcard:given-name
IRI | https://model.ccmm.cz/research-data/Person.givenName
Název | given name (@en)
Definice | The given name associated with the person. (@en)
Definiční obor | Person (@en) [0..*]
Obor hodnot | xsd:string [0..*]
Profiluje | vlastnost given name (@en) (vcard:given-name) Definice: The given name associated with the object

#### has affiliation (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasAffiliation
IRI | https://model.ccmm.cz/research-data/Person.hasAffiliation
Název | has affiliation (@en)
Definice | Affiliation of the person to an organization. (@en)
Definiční obor | Person (@en)
Obor hodnot | Organization (@en) [0..*]
Profiluje | vlastnost has affiliation (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasAffiliation) Definice:

#### Provenance Statement (@en)

IRI profilovaných tříd | dcterms:ProvenanceStatement
IRI | https://model.ccmm.cz/research-data/ProvenanceStatement
Název | Provenance Statement (@en)
Definice | Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation. (@en)
Profiluje | profil Provenance Statement (@en) (https://mff-uk.github.io/specifications/dcat-ap#ProvenanceStatement) třída Provenance Statement (@en) (dcterms:ProvenanceStatement) Definice: Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation.

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/ProvenanceStatement.label
Název | label (@en)
Definice | Provenance state label. (@en)
Definiční obor | Provenance Statement (@en) [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### Resource (@en)

IRI profilovaných tříd | rdfs:Resource
IRI | https://model.ccmm.cz/research-data/Resource
Název | Resource (@en)
Definice | Resource represents any resource, physical or digital, that is related to the described dataset. (@en)
Profiluje | třída Resource (@en) (rdfs:Resource) Definice: The class resource, everything.
Popis použití v profilu | Class is used for description of the resource together with the type of relation, for which is used value from codelist https://vocabs.ccmm.cz/registry/codelist/RelationType/. Distributions of the datasets SHALL NOT be modeled as related resource, but as a distribution. Use qualified resource property to link to the dataset class. Examples of resources: other related dataset, used methodology, instrument used for measurement, conference or conference paper etc... (@en)

Zpětné asociace

- z domény →
- z domény →
- z domény →

#### has identifier (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier
IRI | https://model.ccmm.cz/research-data/Resource.hasIdentifier
Název | has identifier (@en)
Definice | Relation to resource identifier. (@en)
Definiční obor | Resource (@en)
Obor hodnot | Identifier (@en) [0..*]
Profiluje | vlastnost has identifier (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasIdentifier) Definice: has identifier

#### has resource relation type (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasType
IRI | https://model.ccmm.cz/research-data/Resource.hasResourceRelationType
Název | has resource relation type (@en)
Definice | Relation to the relation type between dataset and resource. (@en)
Definiční obor | Resource (@en)
Obor hodnot | Resource relation type (@en) [0..1]
Profiluje | vlastnost has type (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasType) Definice: Reference to the codelist value giving the specific type to the attribute.
Popis použití v profilu | Use value from https://vocabs.ccmm.cz/registry/codelist/RelationType/. (@en)

#### has resource type (@en)

IRI profilovaných vztahů | dcterms:type
IRI | https://model.ccmm.cz/research-data/Resource.type
Název | has resource type (@en)
Definice | A resource type of the related resource. (@en)
Definiční obor | Resource (@en)
Obor hodnot | Resource type (@en) [0..1]
Profiluje | vlastnost Type (@en) (dcterms:type) Definice: The nature or genre of the resource.
Popis použití v profilu | Use IRI identifier of a value from the register https://vocabularies.coar-repositories.org/resource_types/. (@en)

#### has time reference (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasTimeReference
IRI | https://model.ccmm.cz/research-data/Resource.hasTimeReference
Název | has time reference (@en)
Definice | Reference to events related to the resource. (@en)
Definiční obor | Resource (@en)
Obor hodnot | Time reference (@en) [0..*]
Profiluje | vlastnost has time reference (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasTimeReference) Definice:

#### qualified relation (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#qualifiedRelation
IRI | https://model.ccmm.cz/research-data/Resource.qualifiedRelation
Název | qualified relation (@en)
Definice | Link to a description of a relationship between resource and an agent with the specification of the role of agent in this relationship. (@en)
Definiční obor | Resource (@en)
Obor hodnot | Resource to agent relationship (@en) [0..*]
Profiluje | vlastnost qualified relation (@en) (https://model.ccmm.cz/vocabulary/ccmm#qualifiedRelation) Definice:
Popis použití v profilu | (@en)

#### resource URL (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#resourceUrl
IRI | https://model.ccmm.cz/research-data/Resource.resourceURL
Název | resource URL (@en)
Definice | Resolvable URL representing the resource, preferably human readable. (@en)
Definiční obor | Resource (@en) [0..*]
Obor hodnot | xsd:anyURI [0..1]
Profiluje | vlastnost Resource URL (@en) (https://model.ccmm.cz/vocabulary/ccmm#resourceUrl) Definice: Resolvable URL representing the resource, preferably human readable.
Popis použití v profilu | In case it is filled, it must be filled the same in c:iri. If there are more resolvable IRIs, Resource URL shall link to human readable version, machine readable ID is always in c:iri. (@en)

#### title (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#relatedItemTitle
IRI | https://model.ccmm.cz/research-data/Resource.title
Název | title (@en)
Definice | Title of the resource related to the dataset. (@en)
Definiční obor | Resource (@en) [0..*]
Obor hodnot | xsd:string [0..1]
Profiluje | vlastnost title (@en) (https://model.ccmm.cz/vocabulary/datacite#relatedItemTitle) Definice: Title of the related item.

#### Resource agent role type (@en)

IRI profilovaných tříd | skos:Concept
IRI | https://model.ccmm.cz/research-data/ResourceAgentRoleType
Název | Resource agent role type (@en)
Definice | Role of the agent in the relationship to the resource. (@en)
Profiluje | třída Concept (@en) (skos:Concept) Definice: An idea or notion; a unit of thought.
Popis použití v profilu | Use value from code list https://vocabs.ccmm.cz/registry/codelist/AgentRole/. (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/ResourceAgentRoleType.label
Název | label (@en)
Definice | Resource agent role type label. (@en)
Definiční obor | Resource agent role type (@en) [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.
Popis použití v profilu | Use label of the corresponding value from code list https://vocabs.ccmm.cz/registry/codelist/AgentRole/. (@en)

#### Resource relation type (@en)

IRI profilovaných tříd | skos:Concept
IRI | https://model.ccmm.cz/research-data/ResourceRelationType
Název | Resource relation type (@en)
Definice | Type of the relation between the dataset and given resource. (@en)
Profiluje | třída Concept (@en) (skos:Concept) Definice: An idea or notion; a unit of thought.
Popis použití v profilu | Use value from the codelist https://vocabs.ccmm.cz/registry/codelist/RelationType/. (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/ResourceRelationType.label
Název | label (@en)
Definice | Label of the relation type. (@en)
Definiční obor | Resource relation type (@en)
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.
Popis použití v profilu | Use label of corresponding value from code list https://vocabs.ccmm.cz/registry/codelist/RelationType/. (@en)

#### Resource to agent relationship (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/ccmm#ResourceToAgentRelationship
IRI | https://model.ccmm.cz/research-data/ResourceToAgentRelationship
Název | Resource to agent relationship (@en)
Definice | An association class for attaching additional information to a relationship between Resource and Agent. (@en)
Profiluje | třída Resource to agent relationship (@en) (https://model.ccmm.cz/vocabulary/ccmm#ResourceToAgentRelationship) Definice: An association class for attaching additional information to a relationship between Dataset and Agent.
Popis použití v profilu | Use to characterize a relationship between resources and agents, where the nature of the relationship is known but is not adequately characterized by the standard DCTERMS properties (dcterms:hasPart, dcterms:isPartOf, dcterms:conformsTo, dcterms:isFormatOf, dcterms:hasFormat, dcterms:isVersionOf, dcterms:hasVersion, dcterms:replaces, dcterms:isReplacedBy, dcterms:references, dcterms:isReferencedBy, dcterms:requires, dcterms:isRequiredBy) or PROV-O properties (prov:wasDerivedFrom, prov:wasInfluencedBy, prov:wasQuotedFrom, prov:wasRevisionOf, prov:hadPrimarySource, prov:alternateOf, prov:specializationOf). Roles of the agent in the relation are specified using had role relation. (@en)

Zpětné asociace

- z domény →
- z domény →
- z domény →

#### has related agent (@en)

IRI profilovaných vztahů | dcterms:relation
IRI | https://model.ccmm.cz/research-data/ResourceToAgentRelationship.hasRelatedAgent
Název | has related agent (@en)
Definice | Specifies the agent an a given role in the relationship with the resource. (@en)
Definiční obor | Resource to agent relationship (@en)
Obor hodnot | Agent (@en) [1..1]
Profiluje | profil relation (@en) (https://mff-uk.github.io/specifications/dcat-ap#Relationship.relation) profil relation (@en) (https://mff-uk.github.io/specifications/dcat-dap#Relationship.relation) Definice: The resource related to the source resource. vlastnost Relation (@en) (dcterms:relation) Definice: A related resource.

#### sehraná role

IRI profilovaných vztahů | dcat:hadRole
IRI | https://model.ccmm.cz/research-data/ResourceToAgentRelationship.hadRole
Název | sehraná role
Definice | Funkce entity či agenta ve vztahu k jiné entitě či zdroji.
Definiční obor | Resource to agent relationship (@en)
Obor hodnot | Resource agent role type (@en) [1..1]
Profiluje | profil sehraná role (https://mff-uk.github.io/specifications/dcat-ap#Relationship.hadRole) profil sehraná role (https://mff-uk.github.io/specifications/dcat-dap#Relationship.hadRole) vlastnost sehraná role (dcat:hadRole) Definice: Funkce entity či agenta ve vztahu k jiné entitě či zdroji.
Popis použití v profilu | May be used in a qualified-attribution to specify the role of an Agent with respect to an Entity. It is recommended that the value be taken from a controlled vocabulary of agent roles. (@en)

#### Resource type (@en)

IRI profilovaných tříd | skos:Concept
IRI | https://model.ccmm.cz/research-data/ResourceType
Název | Resource type (@en)
Definice | Type of the resource. (@en)
Profiluje | třída Concept (@en) (skos:Concept) Definice: An idea or notion; a unit of thought.
Popis použití v profilu | Use IRI identifier of the resource type from the codelist https://vocabularies.coar-repositories.org/resource_types/. (@en)

Zpětné asociace

- z domény →
- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/ResourceType.label
Název | label (@en)
Definice | Label of the resource type. (@en)
Definiční obor | Resource type (@en)
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### Subject (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/datacite#Subject
IRI | https://model.ccmm.cz/research-data/Subject
Název | Subject (@en)
Definice | Subject, keyword, classification code, or key phrase describing the resource. (@en)
Profiluje | třída Subject (@en) (https://model.ccmm.cz/vocabulary/datacite#Subject) Definice: Subject, keyword, classification code, or key phrase describing the resource.
Popis použití v profilu | Recommended approach is to use controlled list values, preferably in the form of IRI. (@en)

Zpětné asociace

- z domény →

#### classification code (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#subjectClassificationCode
IRI | https://model.ccmm.cz/research-data/Subject.classificationCode
Název | classification code (@en)
Definice | The classification code used for notation of the subject term in the subject scheme. (@en)
Definiční obor | Subject (@en) [0..*]
Obor hodnot | xsd:string [0..1]
Profiluje | vlastnost subject classification code (@en) (https://model.ccmm.cz/vocabulary/datacite#subjectClassificationCode) Definice: The classification code used for the subject term in the subject scheme.

#### definition (@en)

IRI profilovaných vztahů | skos:definition
IRI | https://model.ccmm.cz/research-data/Subject.definition
Název | definition (@en)
Definice | Definition of the subject in the given context. (@en)
Definiční obor | Subject (@en) [0..*]
Obor hodnot | Text [0..*]
Profiluje | vlastnost definition (@en) (skos:definition) Definice: A statement or formal explanation of the meaning of a concept.
Popis použití v profilu | Context is usually given by the subject scheme representing specific thesauri, vocabulary or simply a context (domain specific group at an university etc.). (@en)

#### in subject scheme (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#inSubjectScheme
IRI | https://model.ccmm.cz/research-data/Subject.inSubjectScheme
Název | in subject scheme (@en)
Definice | Belonging of the subject to the subject scheme. (@en)
Definiční obor | Subject (@en)
Obor hodnot | Subject scheme (@en) [0..1]
Profiluje | vlastnost in subject scheme (@en) (https://model.ccmm.cz/vocabulary/ccmm#inSubjectScheme) Definice:

#### title (@en)

IRI profilovaných vztahů | dcterms:title
IRI | https://model.ccmm.cz/research-data/Subject.title
Název | title (@en)
Definice | Title of the subject. (@en)
Definiční obor | Subject (@en) [0..*]
Obor hodnot | rdf:langString [1..*]
Profiluje | vlastnost Title (@en) (dcterms:title) Definice: A name given to the resource.

#### Subject scheme (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/ccmm#SubjectScheme
IRI | https://model.ccmm.cz/research-data/SubjectScheme
Název | Subject scheme (@en)
Definice | Collection of subjects (keywords, concepts, classification codes) curated by a single source. (@en)
Profiluje | třída Subject scheme (@en) (https://model.ccmm.cz/vocabulary/ccmm#SubjectScheme) Definice: Collection of subjects (keywords, concepts, classification codes) curated by a single source.
Popis použití v profilu | Subject scheme sets a contexts for all subjects within this scheme. It usually represents thesauri, vocabulary etc., but may also represent a set of concepts with the meaning of the same context, such as domain specific nomenclature. (@en)

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/SubjectScheme.label
Název | label (@en)
Definice | Label of the subject scheme. (@en)
Definiční obor | Subject scheme (@en) [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

#### Terms of use (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/datacite#Rights
IRI | https://model.ccmm.cz/research-data/TermsOfUse
Název | Terms of use (@en)
Definice | Terms of use defines overall conditions and rights regarding access and usage of dataset. (@en)
Profiluje | třída Rights (@en) (https://model.ccmm.cz/vocabulary/datacite#Rights) Definice: Any rights information for this resource. The property may be repeated to record complex rights characteristics.
Popis použití v profilu | (@en)

Zpětné asociace

- z domény →

#### access rights (@en)

IRI profilovaných vztahů | dcterms:accessRights
IRI | https://model.ccmm.cz/research-data/TermsOfUse.accessRights
Název | access rights (@en)
Definice | Information about the conditions to access the resource or an indication of its security status. (@en)
Definiční obor | Terms of use (@en)
Obor hodnot | Access rights (@en) [1..1]
Profiluje | vlastnost Access Rights (@en) (dcterms:accessRights) Definice: Information about who access the resource or an indication of its security status.

#### description (@en)

IRI profilovaných vztahů | dcterms:description
IRI | https://model.ccmm.cz/research-data/TermsOfUse.Description
Název | description (@en)
Definice | Descriptive text on details of rights and licensing. (@en)
Definiční obor | Terms of use (@en) [0..*]
Obor hodnot | Text [0..*]
Profiluje | vlastnost Description (@en) (dcterms:description) Definice: An account of the resource.

#### has license (@en)

IRI profilovaných vztahů | dcterms:license
IRI | https://model.ccmm.cz/research-data/TermsOfUse.license
Název | has license (@en)
Definice | Reference to the legal document giving official permission to do something with the resource. (@en)
Definiční obor | Terms of use (@en)
Obor hodnot | License Document (@en) [1..1]
Profiluje | vlastnost License (@en) (dcterms:license) Definice: A legal document giving official permission to do something with the resource.

#### kontaktní bod

IRI profilovaných vztahů | dcat:contactPoint
IRI | https://model.ccmm.cz/research-data/TermsOfUse.hasContactPoint
Název | kontaktní bod
Definice | Relevantní kontaktní informace pro katalogizovaný zdroj. Doporučuje se použít slovník VCard.
Definiční obor | Terms of use (@en)
Obor hodnot | Agent (@en) [0..*]
Profiluje | vlastnost kontaktní bod (dcat:contactPoint) Definice: Relevantní kontaktní informace pro katalogizovaný zdroj. Doporučuje se použít slovník VCard.

#### Time instant (@en)

IRI profilovaných tříd | time:Instant
IRI | https://model.ccmm.cz/research-data/TimeInstant
Název | Time instant (@en)
Definice | A temporal entity with zero extent or duration. (@en)
Profiluje | třída Time instant (@en) (time:Instant) Definice: A temporal entity with zero extent or duration
Popis použití v profilu | Use for representation of time reference with zero extent or duration. (@en)

Zpětné asociace

- z domény →
- z domény →

#### date (@en)

IRI profilovaných vztahů | time:inXSDDate
IRI | https://model.ccmm.cz/research-data/TimeInstant.date
Název | date (@en)
Definice | Position of an instant, expressed using xsd:date. (@en)
Definiční obor | Time instant (@en)
Obor hodnot | xsd:date [0..1]
Profiluje | vlastnost in XSD date (@en) (time:inXSDDate) Definice: Position of an instant, expressed using xsd:date
Popis použití v profilu | Each time instant SHALL have exactly one date OR date time stamp attribute. (@en)

#### date time (@en)

IRI profilovaných vztahů | time:inXSDDateTime
IRI | https://model.ccmm.cz/research-data/TimeInstant.dateTime
Název | date time (@en)
Definice | Date with timestamp represented as xsd:dateTime. (@en)
Definiční obor | Time instant (@en)
Obor hodnot | xsd:dateTime [0..1]
Profiluje | vlastnost in XSD Date-Time (@en) (time:inXSDDateTime) Definice: Position of an instant, expressed using xsd:dateTime
Popis použití v profilu | Each time instant SHALL have exactly one date OR date time attribute. Maintanance note: In the draft on newest version of Time ontology, in XSD date-time is deprecated and replaced with in XSD date-time-stamp. (@en)

#### Time interval (@en)

IRI profilovaných tříd | time:Interval
IRI | https://model.ccmm.cz/research-data/TimeInterval
Název | Time interval (@en)
Definice | A temporal entity with an extent or duration (@en)
Profiluje | třída Time interval (@en) (time:Interval) Definice: A temporal entity with an extent or duration
Popis použití v profilu | Use for representation of time reference represented as an interval. Interval is represented by beginning and end time instants. (@en)

#### has beginning (@en)

IRI profilovaných vztahů | time:hasBeginning
IRI | https://model.ccmm.cz/research-data/TimeInterval.hasBeginning
Název | has beginning (@en)
Definice | Time instant representing the beginning of a temporal interval. (@en)
Definiční obor | Time interval (@en)
Obor hodnot | Time instant (@en) [1..1]
Profiluje | vlastnost has beginning (@en) (time:hasBeginning) Definice: Beginning of a temporal entity

#### has end (@en)

IRI profilovaných vztahů | time:hasEnd
IRI | https://model.ccmm.cz/research-data/TimeInterval.hasEnd
Název | has end (@en)
Definice | Time instant representing the end of a temporal interval. (@en)
Definiční obor | Time interval (@en)
Obor hodnot | Time instant (@en) [1..1]
Profiluje | vlastnost has end (@en) (time:hasEnd) Definice: End of a temporal entity.

#### Time reference (@en)

IRI profilovaných tříd | time:TemporalEntity
IRI | https://model.ccmm.cz/research-data/TimeReference
Název | Time reference (@en)
Definice | A temporal interval or instant on which something relevant to the resource has happened. (@en)
Profiluje | třída Temporal entity (@en) (time:TemporalEntity) Definice: A temporal interval or instant.

Zpětné asociace

- z domény →
- z domény →

#### date information (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/datacite#dateInformation
IRI | https://model.ccmm.cz/research-data/TimeReference.dateInformation
Název | date information (@en)
Definice | Additional information to the date in text form. (@en)
Definiční obor | Time reference (@en) [0..*]
Obor hodnot | Text [0..1]
Profiluje | vlastnost date information (@en) (https://model.ccmm.cz/vocabulary/datacite#dateInformation) Definice: Specific information about the date, if appropriate.
Popis použití v profilu | Write any additional information needed to understand the meaning of event that happened in the given time. (@en)

#### has date type (@en)

IRI profilovaných vztahů | https://model.ccmm.cz/vocabulary/ccmm#hasType
IRI | https://model.ccmm.cz/research-data/TimeReference.hasDateType
Název | has date type (@en)
Definice | Reference to the codelist of date types. (@en)
Definiční obor | Time reference (@en)
Obor hodnot | Date type (@en) [1..1]
Profiluje | vlastnost has type (@en) (https://model.ccmm.cz/vocabulary/ccmm#hasType) Definice: Reference to the codelist value giving the specific type to the attribute.
Popis použití v profilu | (@en)

#### Validation result (@en)

IRI profilovaných tříd | https://model.ccmm.cz/vocabulary/ccmm#ValidationResult
IRI | https://model.ccmm.cz/research-data/ValidationResult
Název | Validation result (@en)
Definice | Class describing the result of validation testing. It may include validation of metadata, data and/or web services accessing the data. (@en)
Profiluje | třída Validation result (@en) (https://model.ccmm.cz/vocabulary/ccmm#ValidationResult) Definice: Class describing the result of validation testing. It may include validation of metadata, data and/or web services accessing the data.

Zpětné asociace

- z domény →

#### label (@en)

IRI profilovaných vztahů | rdfs:label
IRI | https://model.ccmm.cz/research-data/ValidationResult.label
Název | label (@en)
Definice | Label of the validation result. (@en)
Definiční obor | Validation result (@en) [0..*]
Obor hodnot | rdf:langString [0..*]
Profiluje | vlastnost label (@en) (rdfs:label) Definice: A human-readable name for the subject.

## Specifikace struktury pro Agent

Datová struktura pro Agent. Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Agent, jež je definováno v souboru `../agent/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../identifier/schema.xsd |
Stejný namespace jako hlavní dokument | ../contact-details/schema.xsd |
Stejný namespace jako hlavní dokument | ../organization/schema.xsd |

#### Kořenové entity XSD schématu

- element `agent`
- komplexní typ `agent`

#### Kořenový element `<agent>`

Typ elementu
Obsah
  Obsahem elementu je typ `agent`.

#### Kořenový komplexní typ `agent`

Obsah - výběr jednoho elementu z množiny

- element `<organization>` [1..1]
- element `<person>` [1..1]

#### Element `<organization>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<name>` [1..1]
- element `<alternate_name>` [0..*]
- element `<identifier>` [0..*]
- element `<contact_point>` [0..*]

#### Element `<organization>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<organization>` / `<name>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost name (Name of the agent.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<organization>` / `<alternate_name>`

Význam
  vlastnost alternate name (To specify the organizational name associated with the object)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<organization>` / `<identifier>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost has identifier (has identifier)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.
Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)

#### Element `<organization>` / `<contact_point>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost má kontaktní bod (Relevantní kontaktní informace pro katalogizovaný zdroj. Doporučuje se použít slovník VCard.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `contact_details`.
Význam
  Contact details (Details to contact the agent in a relationship to the resource.)

#### Element `<person>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Person (Physical person. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<name>` [1..1]
- element `<given_name>` [0..*]
- element `<family_name>` [0..*]
- element `<identifier>` [0..*]
- element `<contact_point>` [0..*]
- element `<affiliation>` [0..*]

#### Element `<person>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<person>` / `<name>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost name (Name of the agent.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<person>` / `<given_name>`

Význam
  vlastnost given name (The given name associated with the person.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<person>` / `<family_name>`

Význam
  vlastnost family name (The family name associated with the person.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<person>` / `<identifier>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost has identifier (has identifier)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.
Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)

#### Element `<person>` / `<contact_point>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost má kontaktní bod (Relevantní kontaktní informace pro katalogizovaný zdroj. Doporučuje se použít slovník VCard.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `contact_details`.
Význam
  Contact details (Details to contact the agent in a relationship to the resource.)

#### Element `<person>` / `<affiliation>`

Význam
  vlastnost has affiliation (Affiliation of the person to an organization.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `organization`.
Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )

## Specifikace struktury pro Distribuce

Datová struktura pro Distribuce. Konkrétní reprezentace datové sady. Datová sada může být dostupná v různých serializacích, které se mohou navzájem lišit různými způsoby, mimo jiné přirozeným jazykem, media-typem či formátem, schematickou organizací, časovým a prostorovým rozlišením, úrovní detailu či profily (které mohou specifikovat některé či všechny tyto rozdíly).

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Distribuce, jež je definováno v souboru `../distribution/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../documentation/schema.xsd |
Stejný namespace jako hlavní dokument | ../application-profile/schema.xsd |
Stejný namespace jako hlavní dokument | ../data-service/schema.xsd |
Stejný namespace jako hlavní dokument | ../checksum/schema.xsd |
Stejný namespace jako hlavní dokument | ../media-type/schema.xsd |
Stejný namespace jako hlavní dokument | ../file/schema.xsd |
Stejný namespace jako hlavní dokument | ../format/schema.xsd |

#### Kořenové entity XSD schématu

- element `distribution`
- komplexní typ `distribution`

#### Kořenový element `<distribution>`

Typ elementu
Obsah
  Obsahem elementu je typ `distribution`.

#### Kořenový komplexní typ `distribution`

Obsah - výběr jednoho elementu z množiny

- element `<distribution_-_data_service>` [1..1]
- element `<distribution_-_downloadable_file>` [1..1]

#### Element `<distribution_-_data_service>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Distribution - data service (Physical embodiment of the dataset distribution as a particular data service. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<title>` [1..1]
- element `<description>` [0..*]
- element `<documentation>` [0..*]
- element `<specification>` [0..*]
- element `<access_service>` [0..*]

#### Element `<distribution_-_data_service>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<distribution_-_data_service>` / `<title>`

Význam
  z obecnější třídy Distribuce (Konkrétní reprezentace datové sady. Datová sada může být dostupná v různých serializacích, které se mohou navzájem lišit různými způsoby, mimo jiné přirozeným jazykem, media-typem či formátem, schematickou organizací, časovým a prostorovým rozlišením, úrovní detailu či profily (které mohou specifikovat některé či všechny tyto rozdíly).) → mající vlastnost title
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<distribution_-_data_service>` / `<description>`

Význam
  vlastnost description (A free-text account of the Distribution.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<distribution_-_data_service>` / `<documentation>`

Význam
  vlastnost has documentation (A page or document about this Distribution.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `documentation`.
Význam
  Documentation (A textual resource intended for human consumption that contains information about the data service.)

#### Element `<distribution_-_data_service>` / `<specification>`

Význam
  vlastnost conforms to specification (An established standard to which the distribution conforms.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `application_profile`.
Význam
  Application profile (A standard or other specification to which a metadata record conforms.)

#### Element `<distribution_-_data_service>` / `<access_service>`

Význam
  vlastnost služba pro přístup k datům (Umístění či přístupový bod zpřístupňující distribuci datové sady.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `data_service`.
Význam
  Data service (Umístění či přístupový bod poskytující operace související s hledáním, přistupem k, či výkonem funkcí na datech či souvisejících zdrojích.)

#### Element `<distribution_-_downloadable_file>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Distribution - downloadable file (Physical embodiment of the dataset in a particular format. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<title>` [1..1]
- element `<byte_size>` [1..1]
- element `<checksum>` [0..1]
- element `<conforms_to_schema>` [0..*]
- element `<media_type>` [0..1]
- element `<access_url>` [1..*]
- element `<download_url>` [0..*]
- element `<format>` [1..1]

#### Element `<distribution_-_downloadable_file>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<distribution_-_downloadable_file>` / `<title>`

Význam
  z obecnější třídy Distribuce (Konkrétní reprezentace datové sady. Datová sada může být dostupná v různých serializacích, které se mohou navzájem lišit různými způsoby, mimo jiné přirozeným jazykem, media-typem či formátem, schematickou organizací, časovým a prostorovým rozlišením, úrovní detailu či profily (které mohou specifikovat některé či všechny tyto rozdíly).) → mající vlastnost title
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<distribution_-_downloadable_file>` / `<byte_size>`

Význam
  vlastnost byte size (The size of a Distribution in bytes. )
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:integer`.

#### Element `<distribution_-_downloadable_file>` / `<checksum>`

Význam
  vlastnost has checksum (A mechanism that can be used to verify that the contents of a distribution have not changed.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `checksum`.
Význam
  Checksum (A value that allows the contents of a file to be authenticated.)

#### Element `<distribution_-_downloadable_file>` / `<conforms_to_schema>`

Význam
  vlastnost conforms to schema (An established standard to which the distribution conforms.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `application_profile`.
Význam
  Application profile (A standard or other specification to which a metadata record conforms.)

#### Element `<distribution_-_downloadable_file>` / `<media_type>`

Význam
  vlastnost typ média (Typ média distribuce definovaný v IANA.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `media_type`.
Význam
  Media Type (A file format.)

#### Element `<distribution_-_downloadable_file>` / `<access_url>`

Význam
  vlastnost přístupová adresa (URL zdroje, přes které je přístupná distribuce datové sady. Příkladem může být vstupní stránka, RSS kanál či SPARQL endpoint. Použijte ve všech případech kromě URL souboru ke stažení, pro které je lepší použít dcat:downloadURL.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `file`.
Význam
  File (Digital resource representing collection of data.)

#### Element `<distribution_-_downloadable_file>` / `<download_url>`

Význam
  vlastnost URL souboru ke stažení (URL souboru ke stažení v daném formátu, například CSV nebo RDF soubor. Formát je popsán vlastností distribuce dcterms:format a/nebo dcat:mediaType.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `file`.
Význam
  File (Digital resource representing collection of data.)

#### Element `<distribution_-_downloadable_file>` / `<format>`

Význam
  vlastnost has format (The file format of the distribution.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `format`.
Význam
  Format (Format of downloadable file.)

## Specifikace struktury pro Contact details

Datová struktura pro Contact details. Contact details such as telephone, e-mail address etc.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Contact details, jež je definováno v souboru `../contact-details/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../address/schema.xsd |

#### Kořenové entity XSD schématu

- element `contact_details`
- komplexní typ `contact_details`

#### Kořenový element `<contact_details>`

Typ elementu
Obsah
  Obsahem elementu je typ `contact_details`.

#### Kořenový komplexní typ `contact_details`

Význam
  Contact details (Details to contact the agent in a relationship to the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<dataBox>` [0..*]
- element `<email>` [0..*]
- element `<phone>` [0..*]
- element `<address>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<dataBox>`

Význam
  vlastnost data box (Code of the data box.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<email>`

Význam
  vlastnost email (Email address.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<phone>`

Význam
  vlastnost phone (Phone number)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<address>`

Význam
  vlastnost has address (To specify the components of the delivery address for the object)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `address`.
Význam
  Address (A spatial object that in a human-readable way identifies a fixed location. )

## Specifikace struktury pro Resource

Datová struktura pro Resource. Resource represents any resource, physical or digital, that is related to the described dataset.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Resource, jež je definováno v souboru `../resource/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../resource-to-agent-relationship/schema.xsd |
Stejný namespace jako hlavní dokument | ../time_reference/schema.xsd |
Stejný namespace jako hlavní dokument | ../identifier/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource-type/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource-relation-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `resource`
- komplexní typ `resource`

#### Kořenový element `<resource>`

Typ elementu
Obsah
  Obsahem elementu je typ `resource`.

#### Kořenový komplexní typ `resource`

Význam
  Resource (Resource represents any resource, physical or digital, that is related to the described dataset. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<title>` [0..1]
- element `<resource_url>` [0..1]
- element `<qualified_relation>` [0..*]
- element `<time_reference>` [0..*]
- element `<identifier>` [0..*]
- element `<resource_type>` [0..1]
- element `<resource_relation_type>` [0..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<title>`

Význam
  vlastnost title (Title of the resource related to the dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<resource_url>`

Význam
  vlastnost resource URL (Resolvable URL representing the resource, preferably human readable.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<qualified_relation>`

Význam
  vlastnost qualified relation (Link to a description of a relationship between resource and an agent with the specification of the role of agent in this relationship.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_to_agent_relationship`.
Význam
  Resource to agent relationship (An association class for attaching additional information to a relationship between Resource and Agent.)

#### Element `<time_reference>`

Význam
  vlastnost has time reference (Reference to events related to the resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_reference`.
Význam
  Time interval (A temporal entity with an extent or duration)

#### Element `<identifier>`

Význam
  vlastnost has identifier (Relation to resource identifier.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.
Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)

#### Element `<resource_type>`

Význam
  vlastnost has resource type (A resource type of the related resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_type`.
Význam
  Resource type (Type of the resource.)

#### Element `<resource_relation_type>`

Význam
  vlastnost has resource relation type (Relation to the relation type between dataset and resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_relation_type`.
Význam
  Resource relation type (Type of the relation between the dataset and given resource.)

## Specifikace struktury pro Location

Datová struktura pro Location. Spatial region, named place or geometry representation of a place related to the dataset.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Location, jež je definováno v souboru `../location/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../geometry/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource/schema.xsd |
Stejný namespace jako hlavní dokument | ../location-relation-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `location`
- komplexní typ `location`

#### Kořenový element `<location>`

Typ elementu
Obsah
  Obsahem elementu je typ `location`.

#### Kořenový komplexní typ `location`

Význam
  Location (Spatial region, named place or geometry representation of a place related to the dataset. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<bounding_box>` [0..*]
- element `<name>` [0..*]
- element `<geometry>` [0..1]
- element `<related_object>` [0..*]
- element `<relation_type>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<bounding_box>`

Význam
  vlastnost bounding box (Bounding box of the location geometry.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anySimpleType`.

#### Element `<name>`

Význam
  vlastnost name (Name of the spatial location.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<geometry>`

Význam
  vlastnost has geometry (The corresponding geometry for a resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `geometry`.
Význam
  Geometry (The Geometry class provides the means to identify a location as a point, line, polygon, etc. expressed using coordinates in some coordinate reference system.)

#### Element `<related_object>`

Význam
  vlastnost has related object (Relation to the spatial object.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource`.
Význam
  Resource (Resource represents any resource, physical or digital, that is related to the described dataset. )

#### Element `<relation_type>`

Význam
  vlastnost has location relation type (Relation of the location to the dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `relation_type`.
Význam
  Location relation type (Relation of the dataset to the resource.)

## Specifikace struktury pro Time reference

Datová struktura pro Time reference. A temporal interval or instant on which something relevant to the resource has happened.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Time reference, jež je definováno v souboru `../time_reference/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../time-instant/schema.xsd |
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../date-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `time_reference`
- komplexní typ `time_reference`

#### Kořenový element `<time_reference>`

Typ elementu
Obsah
  Obsahem elementu je typ `time_reference`.

#### Kořenový komplexní typ `time_reference`

Obsah - výběr jednoho elementu z množiny

- element `<time_interval>` [1..1]
- element `<time_instant>` [1..1]

#### Element `<time_interval>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Time interval (A temporal entity with an extent or duration)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<beginning_time_instant>` [1..1]
- element `<end_time_instant>` [1..1]
- element `<date_information>` [0..1]
- element `<date_type>` [1..1]

#### Element `<time_interval>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<time_interval>` / `<beginning_time_instant>`

Význam
  vlastnost has beginning (Time instant representing the beginning of a temporal interval.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_instant`.
Význam
  Time instant (A temporal entity with zero extent or duration.)

#### Element `<time_interval>` / `<end_time_instant>`

Význam
  vlastnost has end (Time instant representing the end of a temporal interval.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_instant`.
Význam
  Time instant (A temporal entity with zero extent or duration.)

#### Element `<time_interval>` / `<date_information>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost date information (Additional information to the date in text form.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<time_interval>` / `<date_type>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost has date type (Reference to the codelist of date types.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `date_type`.
Význam
  Date type (Type of a date in relation to the resource.)

#### Element `<time_instant>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Význam
  Time instant (A temporal entity with zero extent or duration.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<date_information>` [0..1]
- element `<date_type>` [1..1]
- výběr jednoho prvku [1..1]
  - element `<date_time>` [1..1]
  - element `<date>` [1..1]

#### Element `<time_instant>` / `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<time_instant>` / `<date_information>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost date information (Additional information to the date in text form.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<time_instant>` / `<date_type>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost has date type (Reference to the codelist of date types.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `date_type`.
Význam
  Date type (Type of a date in relation to the resource.)

#### Element `<time_instant>` / `<date_time>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:dateTime`.

#### Element `<time_instant>` / `<date>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:date`.

## Specifikace struktury pro Funding reference

Datová struktura pro Funding reference. Information about financial support (funding) for the resource being registered.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Funding reference, jež je definováno v souboru `../funding-reference/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../agent/schema.xsd |

#### Kořenové entity XSD schématu

- element `funding_reference`
- komplexní typ `funding_reference`

#### Kořenový element `<funding_reference>`

Typ elementu
Obsah
  Obsahem elementu je typ `funding_reference`.

#### Kořenový komplexní typ `funding_reference`

Význam
  Funding reference (Information about financial support (funding) for the resource being registered.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<funding_program>` [0..1]
- element `<award_title>` [0..1]
- element `<local_identifier>` [0..1]
- element `<funder>` [1..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<funding_program>`

Význam
  vlastnost funding program (Reference to the specific funding program.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<award_title>`

Význam
  vlastnost award title ( The human readable title or name of the award (grant).)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<local_identifier>`

Význam
  vlastnost local identifier (The code assigned by the funder to a sponsored award (grant).)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<funder>`

Význam
  vlastnost has funder (Relation to the agent entity of a funder.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `agent`.
Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )

## Specifikace struktury pro Terms of use

Datová struktura pro Terms of use. Terms of use defines overall conditions and rights regarding access and usage of dataset.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Terms of use, jež je definováno v souboru `../terms-of-use/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../access-rights/schema.xsd |
Stejný namespace jako hlavní dokument | ../license-document/schema.xsd |
Stejný namespace jako hlavní dokument | ../agent/schema.xsd |

#### Kořenové entity XSD schématu

- element `terms_of_use`
- komplexní typ `terms_of_use`

#### Kořenový element `<terms_of_use>`

Typ elementu
Obsah
  Obsahem elementu je typ `terms_of_use`.

#### Kořenový komplexní typ `terms_of_use`

Význam
  Terms of use (Terms of use defines overall conditions and rights regarding access and usage of dataset. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<description>` [0..*]
- element `<access_rights>` [1..1]
- element `<license>` [1..1]
- element `<contact_point>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<description>`

Význam
  vlastnost description (Descriptive text on details of rights and licensing.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<access_rights>`

Význam
  vlastnost access rights (Information about the conditions to access the resource or an indication of its security status.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `access_rights`.
Význam
  Access rights (A statement about the access rights to the dataset.)

#### Element `<license>`

Význam
  vlastnost has license (Reference to the legal document giving official permission to do something with the resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `license_document`.
Význam
  License Document (A legal document giving official permission to do something with a resource.)

#### Element `<contact_point>`

Význam
  vlastnost kontaktní bod (Relevantní kontaktní informace pro katalogizovaný zdroj. Doporučuje se použít slovník VCard.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `agent`.
Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )

## Specifikace struktury pro Resource to Agent Relationship

Datová struktura pro Resource to Agent Relationship. An association class for attaching additional information to a relationship between Dataset and Agent.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Resource to Agent Relationship, jež je definováno v souboru `../resource-to-agent-relationship/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../agent/schema.xsd |

#### Kořenové entity XSD schématu

- element `resource_to_agent_relationship`
- komplexní typ `resource_to_agent_relationship`

#### Kořenový element `<resource_to_agent_relationship>`

Typ elementu
Obsah
  Obsahem elementu je typ `resource_to_agent_relationship`.

#### Kořenový komplexní typ `resource_to_agent_relationship`

Význam
  Resource to agent relationship (An association class for attaching additional information to a relationship between Resource and Agent.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<role>` [1..1]
- element `<relation>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<role>`

Význam
  vlastnost sehraná role (Funkce entity či agenta ve vztahu k jiné entitě či zdroji.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<relation>`

Význam
  vlastnost has related agent (Specifies the agent an a given role in the relationship with the resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `agent`.
Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )

## Specifikace struktury pro Resource agent role type

Datová struktura pro Resource agent role type. An idea or notion; a unit of thought.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Resource agent role type, jež je definováno v souboru `../resource-agent-role-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Nic není importováno.

#### Kořenové entity XSD schématu

- element `resource_agent_role_type`
- komplexní typ `resource_agent_role_type`

#### Kořenový element `<resource_agent_role_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `resource_agent_role_type`.

#### Kořenový komplexní typ `resource_agent_role_type`

Význam
  Resource agent role type (Role of the agent in the relationship to the resource. )
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

## Specifikace struktury pro Application profile

Datová struktura pro Application profile. A standard or other specification to which a metadata record conforms.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Application profile, jež je definováno v souboru `../application-profile/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `application_profile`
- komplexní typ `application_profile`

#### Kořenový element `<application_profile>`

Typ elementu
Obsah
  Obsahem elementu je typ `application_profile`.

#### Kořenový komplexní typ `application_profile`

Význam
  Application profile (A standard or other specification to which a metadata record conforms.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of application profile)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Media Type

Datová struktura pro Media Type. A file format or physical medium.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Media Type, jež je definováno v souboru `../media-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `media_type`
- komplexní typ `media_type`

#### Kořenový element `<media_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `media_type`.

#### Kořenový komplexní typ `media_type`

Význam
  Media Type (A file format.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Media type label.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro File

Datová struktura pro File. Downloadable file in given format.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro File, jež je definováno v souboru `../file/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `file`
- komplexní typ `file`

#### Kořenový element `<file>`

Typ elementu
Obsah
  Obsahem elementu je typ `file`.

#### Kořenový komplexní typ `file`

Význam
  File (Digital resource representing collection of data.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (File label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Validation result

Datová struktura pro Validation result. Class describing the result of validation testing. It may include validation of metadata, data and/or web services accessing the data.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Validation result, jež je definováno v souboru `../validation-result/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `validation_result`
- komplexní typ `validation_result`

#### Kořenový element `<validation_result>`

Typ elementu
Obsah
  Obsahem elementu je typ `validation_result`.

#### Kořenový komplexní typ `validation_result`

Význam
  Validation result (Class describing the result of validation testing. It may include validation of metadata, data and/or web services accessing the data.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the validation result.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Subject scheme

Datová struktura pro Subject scheme. Collection of subjects (keywords, concepts, classification codes) curated by a single source.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Subject scheme, jež je definováno v souboru `../subject-scheme/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `subject_scheme`
- komplexní typ `subject_scheme`

#### Kořenový element `<subject_scheme>`

Typ elementu
Obsah
  Obsahem elementu je typ `subject_scheme`.

#### Kořenový komplexní typ `subject_scheme`

Význam
  Subject scheme (Collection of subjects (keywords, concepts, classification codes) curated by a single source.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the subject scheme.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Address

Datová struktura pro Address. An "address representation" as conceptually defined by the INSPIRE Address Representation data type. The locn:addressId property may be used to link this locn:Address to other representations.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Address, jež je definováno v souboru `../address/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `address`
- komplexní typ `address`

#### Kořenový element `<address>`

Typ elementu
Obsah
  Obsahem elementu je typ `address`.

#### Kořenový komplexní typ `address`

Význam
  Address (A spatial object that in a human-readable way identifies a fixed location. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<label>` [0..*]
- element `<full_address>` [0..*]
- element `<po_box>` [0..*]
- element `<thoroughfare>` [0..*]
- element `<locator_designator>` [0..*]
- element `<locator_name>` [0..*]
- element `<address_area>` [0..*]
- element `<post_name>` [0..*]
- element `<administrative_unit_level_1>` [0..*]
- element `<administrative_unit_level_2>` [0..*]
- element `<post_code>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Address label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<full_address>`

Význam
  vlastnost full address (The complete address written as a string.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<po_box>`

Význam
  vlastnost post office box (A location designator for a postal delivery point at a post office, usually a number.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<thoroughfare>`

Význam
  vlastnost thoroughfare (The name of a passage or way through from one location to another.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<locator_designator>`

Význam
  vlastnost locator designator (A number or sequence of characters that uniquely identifies the locator within the relevant scope.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<locator_name>`

Význam
  vlastnost locator name (Proper noun(s) applied to the real world entity identified by the locator. The locator name could be the name of the property or complex, of the building or part of the building, or it could be the name of a room inside a building.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<address_area>`

Význam
  vlastnost address area (The name of a geographic area that groups Addresses.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<post_name>`

Význam
  vlastnost post name (A name created and maintained for postal purposes to identify a subdivision of addresses and postal delivery points. )
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<administrative_unit_level_1>`

Význam
  vlastnost administrative unit level 1 (The name of the uppermost level of the address, almost always a country.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<administrative_unit_level_2>`

Význam
  vlastnost administrative unit level 2 (The name of a secondary level/region of the address, usually a county, state or other such area that typically encompasses several localities.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<post_code>`

Význam
  vlastnost post code (The code created and maintained for postal purposes to identify a subdivision of addresses and postal delivery points.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

## Specifikace struktury pro Provenance Statement

Datová struktura pro Provenance Statement. Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Provenance Statement, jež je definováno v souboru `../provenance-statement/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `provenance_statement`
- komplexní typ `provenance_statement`

#### Kořenový element `<provenance_statement>`

Typ elementu
Obsah
  Obsahem elementu je typ `provenance_statement`.

#### Kořenový komplexní typ `provenance_statement`

Význam
  Provenance Statement (Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Provenance state label.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Media Type

Datová struktura pro Media Type. A file format or physical medium.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Media Type, jež je definováno v souboru `../media-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `media_type`
- komplexní typ `media_type`

#### Kořenový element `<media_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `media_type`.

#### Kořenový komplexní typ `media_type`

Význam
  Media Type (A file format.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Media type label.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Subject

Datová struktura pro Subject. Subject, keyword, classification code, or key phrase describing the resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Subject, jež je definováno v souboru `../subject/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../subject-scheme/schema.xsd |

#### Kořenové entity XSD schématu

- element `subject`
- komplexní typ `subject`

#### Kořenový element `<subject>`

Typ elementu
Obsah
  Obsahem elementu je typ `subject`.

#### Kořenový komplexní typ `subject`

Význam
  Subject (Subject, keyword, classification code, or key phrase describing the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<definition>` [0..*]
- element `<title>` [1..*]
- element `<classification_code>` [0..1]
- element `<subject_scheme>` [0..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<definition>`

Význam
  vlastnost definition (Definition of the subject in the given context.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<title>`

Význam
  vlastnost title (Title of the subject.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<classification_code>`

Význam
  vlastnost classification code (The classification code used for notation of the subject term in the subject scheme.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<subject_scheme>`

Význam
  vlastnost in subject scheme (Belonging of the subject to the subject scheme.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `subject_scheme`.
Význam
  Subject scheme (Collection of subjects (keywords, concepts, classification codes) curated by a single source.)

## Specifikace struktury pro Katalogizační záznam

Datová struktura pro Katalogizační záznam. Záznam v datovém katalogu popisující jednu datovou sadu či datovou službu.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Katalogizační záznam, jež je definováno v souboru `../metadata-record/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../repository/schema.xsd |
Stejný namespace jako hlavní dokument | ../application-profile/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource-to-agent-relationship/schema.xsd |
Stejný namespace jako hlavní dokument | ../language-system/schema.xsd |

#### Kořenové entity XSD schématu

- element `metadata_record`
- komplexní typ `metadata_record`

#### Kořenový element `<metadata_record>`

Typ elementu
Obsah
  Obsahem elementu je typ `metadata_record`.

#### Kořenový komplexní typ `metadata_record`

Význam
  Katalogizační záznam (Záznam v datovém katalogu popisující jednu datovou sadu či datovou službu.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<date_updated>` [0..*]
- element `<date_created>` [0..1]
- element `<original_repository>` [0..*]
- element `<conforms_to_standard>` [0..*]
- element `<qualified_relation>` [1..*]
- element `<language>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<date_updated>`

Význam
  vlastnost date updated (Date on which the resource was changed.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:date`.

#### Element `<date_created>`

Význam
  vlastnost date created (The date on which the metadata record was created.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:date`.

#### Element `<original_repository>`

Význam
  vlastnost has original repository (Link to the repository in which the metadata were originally stored and curated.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `repository`.
Význam
  Katalog (Řízená kolekce metadat o datových sadách a datových službách)

#### Element `<conforms_to_standard>`

Význam
  vlastnost conforms to standard (An established standard to which the metadata record conforms.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `application_profile`.
Význam
  Application profile (A standard or other specification to which a metadata record conforms.)

#### Element `<qualified_relation>`

Význam
  vlastnost kvalifikovaný vztah (Odkaz na popis vztahu s jiným zdrojem.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_to_agent_relationship`.
Význam
  Resource to agent relationship (An association class for attaching additional information to a relationship between Resource and Agent.)

#### Element `<language>`

Význam
  vlastnost language (A language used in the textual metadata describing titles, descriptions of the metadata record.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `language_system`.
Význam
  Language system (A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language.)

## Specifikace struktury pro Katalog

Datová struktura pro Katalog. Řízená kolekce metadat o datových sadách a datových službách

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Katalog, jež je definováno v souboru `../repository/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `repository`
- komplexní typ `repository`

#### Kořenový element `<repository>`

Typ elementu
Obsah
  Obsahem elementu je typ `repository`.

#### Kořenový komplexní typ `repository`

Význam
  Katalog (Řízená kolekce metadat o datových sadách a datových službách)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Human readable name of the repository.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Datová sada

Datová struktura pro Datová sada. Kolekce dat poskytovaná či řízená jedním zdrojem, která je k dispozici pro přístup či stažení v jednom či více formátech.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Datová sada, jež je definováno v souboru `../dataset/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../description/schema.xsd |
Stejný namespace jako hlavní dokument | ../alternate-title/schema.xsd |
Stejný namespace jako hlavní dokument | ../metadata-record/schema.xsd |
Stejný namespace jako hlavní dokument | ../identifier/schema.xsd |
Stejný namespace jako hlavní dokument | ../location/schema.xsd |
Stejný namespace jako hlavní dokument | ../provenance-statement/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource-to-agent-relationship/schema.xsd |
Stejný namespace jako hlavní dokument | ../time_reference/schema.xsd |
Stejný namespace jako hlavní dokument | ../subject/schema.xsd |
Stejný namespace jako hlavní dokument | ../validation-result/schema.xsd |
Stejný namespace jako hlavní dokument | ../distribution/schema.xsd |
Stejný namespace jako hlavní dokument | ../funding-reference/schema.xsd |
Stejný namespace jako hlavní dokument | ../terms-of-use/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource/schema.xsd |
Stejný namespace jako hlavní dokument | ../resource-type/schema.xsd |
Stejný namespace jako hlavní dokument | ../language-system/schema.xsd |

#### Kořenové entity XSD schématu

- element `dataset`
- komplexní typ `dataset`

#### Kořenový element `<dataset>`

Typ elementu
Obsah
  Obsahem elementu je typ `dataset`.

#### Kořenový komplexní typ `dataset`

Význam
  Datová sada (Kolekce dat poskytovaná či řízená jedním zdrojem, která je k dispozici pro přístup či stažení v jednom či více formátech.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<publication_year>` [1..1]
- element `<version>` [0..1]
- element `<title>` [1..1]
- element `<has_description>` [0..*]
- element `<alternate_title>` [0..*]
- element `<is_described_by>` [1..*]
- element `<identifier>` [1..*]
- element `<location>` [0..*]
- element `<provenance>` [0..*]
- element `<qualified_relation>` [2..*]
- element `<time_reference>` [1..*]
- element `<subject>` [1..*]
- element `<validation_result>` [0..*]
- element `<distribution>` [0..*]
- element `<funding_reference>` [0..*]
- element `<terms_of_use>` [1..1]
- element `<related_resource>` [0..*]
- element `<resource_type>` [0..1]
- element `<other_language>` [0..*]
- element `<primary_language>` [0..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<publication_year>`

Význam
  vlastnost publication year (The year when the item was or will be made publicly available.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:gYear`.

#### Element `<version>`

Význam
  vlastnost version (The version indicator (name or identifier) of a resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<title>`

Význam
  vlastnost title (A name given to the dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<has_description>`

Význam
  vlastnost has description (Relation to the description of a dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `description`.
Význam
  Description (All additional information that does not fit in any of the other categories. May be used for technical information or detailed information associated with a scientific instrument.)

#### Element `<alternate_title>`

Význam
  vlastnost has alternate title
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `alternate_title`.
Význam
  Alternate title (Alternate title of the resource.)

#### Element `<is_described_by>`

Význam
  vlastnost is described by (Inverse relation between dataset and metadata record.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `metadata_record`.
Význam
  Katalogizační záznam (Záznam v datovém katalogu popisující jednu datovou sadu či datovou službu.)

#### Element `<identifier>`

Význam
  vlastnost has identifier (has identifier)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.
Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)

#### Element `<location>`

Význam
  vlastnost has location (The geographical area covered by the dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `location`.
Význam
  Location (Spatial region, named place or geometry representation of a place related to the dataset. )

#### Element `<provenance>`

Význam
  vlastnost has provenance (A statement about the lineage of a Dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `provenance_statement`.
Význam
  Provenance Statement (Any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation.)

#### Element `<qualified_relation>`

Význam
  vlastnost qualified relation (Link to a description of a relationship between dataset and an agent with the specification of the role of agent in this relationship.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  2..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_to_agent_relationship`.
Význam
  Resource to agent relationship (An association class for attaching additional information to a relationship between Resource and Agent.)

#### Element `<time_reference>`

Význam
  vlastnost has time reference (Reference to events related to the dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_reference`.
Význam
  Time interval (A temporal entity with an extent or duration)

#### Element `<subject>`

Význam
  vlastnost has subject (Dataset described using a subject.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `subject`.
Význam
  Subject (Subject, keyword, classification code, or key phrase describing the resource.)

#### Element `<validation_result>`

Význam
  vlastnost has validation result (Reference to the report about the dataset validation.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `validation_result`.
Význam
  Validation result (Class describing the result of validation testing. It may include validation of metadata, data and/or web services accessing the data.)

#### Element `<distribution>`

Význam
  vlastnost has distribution (Dostupná distribuce datové sady.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `distribution`.
Význam
  Distribution - data service (Physical embodiment of the dataset distribution as a particular data service. )

#### Element `<funding_reference>`

Význam
  vlastnost has funding reference (Has reference for funding of a dataset acquisition.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `funding_reference`.
Význam
  Funding reference (Information about financial support (funding) for the resource being registered.)

#### Element `<terms_of_use>`

Význam
  vlastnost has terms of use (Terms under which the dataset may be accessed.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `terms_of_use`.
Význam
  Terms of use (Terms of use defines overall conditions and rights regarding access and usage of dataset. )

#### Element `<related_resource>`

Význam
  vlastnost has related resource (Reference to the resource in any way related to the described dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource`.
Význam
  Resource (Resource represents any resource, physical or digital, that is related to the described dataset. )

#### Element `<resource_type>`

Význam
  vlastnost has resource type (A resource type of the Dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource_type`.
Význam
  Resource type (Type of the resource.)

#### Element `<other_language>`

Význam
  vlastnost has other language (Any other languages of the Dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `language_system`.
Význam
  Language system (A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language.)

#### Element `<primary_language>`

Význam
  vlastnost has other language (Any other languages of the Dataset.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `language_system`.
Význam
  Language system (A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language.)

## Specifikace struktury pro Identifier

Datová struktura pro Identifier. This is based on the UN/CEFACT Identifier class.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Identifier, jež je definováno v souboru `../identifier/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../identifier-scheme/schema.xsd |

#### Kořenové entity XSD schématu

- element `identifier`
- komplexní typ `identifier`

#### Kořenový element `<identifier>`

Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.

#### Kořenový komplexní typ `identifier`

Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<value>` [1..1]
- element `<scheme>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<value>`

Význam
  vlastnost value (Value of the identifer within the given identifier scheme.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<scheme>`

Význam
  vlastnost in scheme (Relation between the identifier and scheme in which it is defined and unique.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier_scheme`.
Význam
  Identifier scheme (Scheme in which is the identifier value unique, usually representing some authority. Identifier scheme shall always be represented as IRI identifier.)

## Specifikace struktury pro Alternate title

Datová struktura pro Alternate title. Alternate title f the resource

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Alternate title, jež je definováno v souboru `../alternate-title/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../alternate-title-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `alternate_title`
- komplexní typ `alternate_title`

#### Kořenový element `<alternate_title>`

Typ elementu
Obsah
  Obsahem elementu je typ `alternate_title`.

#### Kořenový komplexní typ `alternate_title`

Význam
  Alternate title (Alternate title of the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<title>` [1..*]
- element `<alternate_title_type>` [0..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<title>`

Význam
  vlastnost title (A human-readable name for the subject.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<alternate_title_type>`

Význam
  vlastnost has alternate title type (Type of the alternate name relation.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `alternate_title_type`.
Význam
  Alternate title type (Type of alternate title.)

## Specifikace struktury pro Geometry

Datová struktura pro Geometry. The Geometry class provides the means to identify a location as a point, line, polygon, etc. expressed using coordinates in some coordinate reference system.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Geometry, jež je definováno v souboru `../geometry/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `geometry`
- komplexní typ `geometry`

#### Kořenový element `<geometry>`

Typ elementu
Obsah
  Obsahem elementu je typ `geometry`.

#### Kořenový komplexní typ `geometry`

Význam
  Geometry (The Geometry class provides the means to identify a location as a point, line, polygon, etc. expressed using coordinates in some coordinate reference system.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<label>` [0..*]
- element `<geography_markup_language_literal>` [0..*]
- element `<well_known_text_literal>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of geometry object.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<geography_markup_language_literal>`

Význam
  vlastnost geography markup language literal (Representation of geometry object as GML Literal.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anySimpleType`.

#### Element `<well_known_text_literal>`

Význam
  vlastnost well known text literal (Representation of geometry object as WKT Literal.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anySimpleType`.

## Specifikace struktury pro Documentation

Datová struktura pro Documentation. A textual resource intended for human consumption that contains information about the data service.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Documentation, jež je definováno v souboru `../documentation/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `documentation`
- komplexní typ `documentation`

#### Kořenový element `<documentation>`

Typ elementu
Obsah
  Obsahem elementu je typ `documentation`.

#### Kořenový komplexní typ `documentation`

Význam
  Documentation (A textual resource intended for human consumption that contains information about the data service.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Documentation label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Data service

Datová struktura pro Data service. Umístění či přístupový bod poskytující operace související s hledáním, přistupem k, či výkonem funkcí na datech či souvisejících zdrojích.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Data service, jež je definováno v souboru `../data-service/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../resource/schema.xsd |

#### Kořenové entity XSD schématu

- element `data_service`
- komplexní typ `data_service`

#### Kořenový element `<data_service>`

Typ elementu
Obsah
  Obsahem elementu je typ `data_service`.

#### Kořenový komplexní typ `data_service`

Význam
  Data service (Umístění či přístupový bod poskytující operace související s hledáním, přistupem k, či výkonem funkcí na datech či souvisejících zdrojích.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]
- element `<endpoint_url>` [1..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Data service label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<endpoint_url>`

Význam
  vlastnost přístupový bod služby (Kořenové umístění nebo hlavní přístupový bod služby (IRI přístupné přes Web).)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `resource`.
Význam
  Resource (Resource represents any resource, physical or digital, that is related to the described dataset. )

## Specifikace struktury pro Checksum

Datová struktura pro Checksum. A value that allows the contents of a file to be authenticated.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Checksum, jež je definováno v souboru `../checksum/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Nic není importováno.

#### Kořenové entity XSD schématu

- element `checksum`
- komplexní typ `checksum`

#### Kořenový element `<checksum>`

Typ elementu
Obsah
  Obsahem elementu je typ `checksum`.

#### Kořenový komplexní typ `checksum`

Význam
  Checksum (A value that allows the contents of a file to be authenticated.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<checksum_value>` [1..1]
- element `<algorithm>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<checksum_value>`

Význam
  vlastnost checksum value (A lower case hexadecimal encoded digest value produced using a specific algorithm. )
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:hexBinary`.

#### Element `<algorithm>`

Význam
  vlastnost uses algorithm (The algorithm used to produce the subject Checksum.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

## Specifikace struktury pro Organization

Datová struktura pro Organization. Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Organization, jež je definováno v souboru `../organization/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../identifier/schema.xsd |
Stejný namespace jako hlavní dokument | ../contact-details/schema.xsd |
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `organization`
- komplexní typ `organization`

#### Kořenový element `<organization>`

Typ elementu
Obsah
  Obsahem elementu je typ `organization`.

#### Kořenový komplexní typ `organization`

Význam
  Organization (Represents a collection of people organized together into a community or other social, commercial or political structure. The group has some common purpose or reason for existence which goes beyond the set of people belonging to it and can act as an Agent. Organizations are often decomposable into hierarchical structures. )
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<name>` [1..1]
- element `<identifier>` [0..*]
- element `<contact_point>` [0..*]
- element `<alternate_name>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<name>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost name (Name of the agent.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<identifier>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost has identifier (has identifier)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `identifier`.
Význam
  Identifier (Unique and resolvable identifier containing the notation and identifier scheme in the form of URI.)

#### Element `<contact_point>`

Význam
  z obecnější třídy Agent (Any entity carrying out actions with respect to the entities Catalogue and the Catalogued Resources.) → mající vlastnost má kontaktní bod (Relevantní kontaktní informace pro katalogizovaný zdroj. Doporučuje se použít slovník VCard.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `contact_details`.
Význam
  Contact details (Details to contact the agent in a relationship to the resource.)

#### Element `<alternate_name>`

Význam
  vlastnost alternate name (To specify the organizational name associated with the object)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro License Document

Datová struktura pro License Document. A legal document giving official permission to do something with a resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro License Document, jež je definováno v souboru `../license-document/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `license_document`
- komplexní typ `license_document`

#### Kořenový element `<license_document>`

Typ elementu
Obsah
  Obsahem elementu je typ `license_document`.

#### Kořenový komplexní typ `license_document`

Význam
  License Document (A legal document giving official permission to do something with a resource.)
Obsah - elementy v tomto pořadí

- element `<label>` [0..*]

#### Element `<label>`

Význam
  vlastnost label (Label of the license document.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Date type

Datová struktura pro Date type. Type of a date in relation to the resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Date type, jež je definováno v souboru `../date-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `date_type`
- komplexní typ `date_type`

#### Kořenový element `<date_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `date_type`.

#### Kořenový komplexní typ `date_type`

Význam
  Date type (Type of a date in relation to the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Date type label.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Resource relation type

Datová struktura pro Resource relation type. Type of the relation between the dataset and given resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Resource relation type, jež je definováno v souboru `../resource-relation-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `resource_relation_type`
- komplexní typ `resource_relation_type`

#### Kořenový element `<resource_relation_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `resource_relation_type`.

#### Kořenový komplexní typ `resource_relation_type`

Význam
  Resource relation type (Type of the relation between the dataset and given resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the relation type.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Resource type

Datová struktura pro Resource type. Type of the resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Resource type, jež je definováno v souboru `../resource-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `resource_type`
- komplexní typ `resource_type`

#### Kořenový element `<resource_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `resource_type`.

#### Kořenový komplexní typ `resource_type`

Význam
  Resource type (Type of the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the resource type.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Location relation type

Datová struktura pro Location relation type. Relation of the dataset to the resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Location relation type, jež je definováno v souboru `../location-relation-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `relation_type`
- komplexní typ `relation_type`

#### Kořenový element `<relation_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `relation_type`.

#### Kořenový komplexní typ `relation_type`

Význam
  Location relation type (Relation of the dataset to the resource.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of location relation type.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Format

Datová struktura pro Format. Format of downloadable file.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Format, jež je definováno v souboru `../format/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `format`
- komplexní typ `format`

#### Kořenový element `<format>`

Typ elementu
Obsah
  Obsahem elementu je typ `format`.

#### Kořenový komplexní typ `format`

Význam
  Format (Format of downloadable file.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of format value.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Alternate title type

Datová struktura pro Alternate title type. Type of alternate title.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Alternate title type, jež je definováno v souboru `../alternate-title-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `alternate_title_type`
- komplexní typ `alternate_title_type`

#### Kořenový element `<alternate_title_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `alternate_title_type`.

#### Kořenový komplexní typ `alternate_title_type`

Význam
  Alternate title type (Type of alternate title.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Alternate title type label.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Access rights

Datová struktura pro Access rights. Access rights to the resource.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Access rights, jež je definováno v souboru `../access-rights/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `access_rights`
- komplexní typ `access_rights`

#### Kořenový element `<access_rights>`

Typ elementu
Obsah
  Obsahem elementu je typ `access_rights`.

#### Kořenový komplexní typ `access_rights`

Význam
  Access rights (A statement about the access rights to the dataset.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the access rights vocabulary value.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Language system

Datová struktura pro Language system. A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Language system, jež je definováno v souboru `../language-system/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `language_system`
- komplexní typ `language_system`

#### Kořenový element `<language_system>`

Typ elementu
Obsah
  Obsahem elementu je typ `language_system`.

#### Kořenový komplexní typ `language_system`

Význam
  Language system (A system of signs, symbols, sounds, gestures, or rules used in communication, e.g. a language.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Language label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Identifier scheme

Datová struktura pro Identifier scheme. Scheme in which is the identifier value unique, usually representing some authority. Identifier scheme shall always be represented as IRI identifier.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Identifier scheme, jež je definováno v souboru `../identifier-scheme/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |

#### Kořenové entity XSD schématu

- element `identifier_scheme`
- komplexní typ `identifier_scheme`

#### Kořenový element `<identifier_scheme>`

Typ elementu
Obsah
  Obsahem elementu je typ `identifier_scheme`.

#### Kořenový komplexní typ `identifier_scheme`

Význam
  Identifier scheme (Scheme in which is the identifier value unique, usually representing some authority. Identifier scheme shall always be represented as IRI identifier.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Identifier scheme label)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

## Specifikace struktury pro Time instant

Datová struktura pro Time instant. A temporal entity with zero extent or duration.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Time instant, jež je definováno v souboru `../time-instant/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../date-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `time_instant`
- komplexní typ `time_instant`

#### Kořenový element `<time_instant>`

Typ elementu
Obsah
  Obsahem elementu je typ `time_instant`.

#### Kořenový komplexní typ `time_instant`

Význam
  Time instant (A temporal entity with zero extent or duration.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<date_information>` [0..1]
- element `<date_type>` [1..1]
- výběr jednoho prvku [1..1]
  - element `<date_time>` [1..1]
  - element `<date>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<date_information>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost date information (Additional information to the date in text form.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<date_type>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost has date type (Reference to the codelist of date types.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `date_type`.
Význam
  Date type (Type of a date in relation to the resource.)

#### Element `<date_time>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:dateTime`.

#### Element `<date>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:date`.

## Specifikace struktury pro Time interval

Datová struktura pro Time interval. A temporal entity with an extent or duration

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Time interval, jež je definováno v souboru `../time-interval/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
``xml | http://www.w3.org/XML/1998/namespace | http://www.w3.org/XML/1998/namespace |
Stejný namespace jako hlavní dokument | ../date-type/schema.xsd |
Stejný namespace jako hlavní dokument | ../time-instant/schema.xsd |

#### Kořenové entity XSD schématu

- element `time_interval`
- komplexní typ `time_interval`

#### Kořenový element `<time_interval>`

Typ elementu
Obsah
  Obsahem elementu je typ `time_interval`.

#### Kořenový komplexní typ `time_interval`

Význam
  Time interval (A temporal entity with an extent or duration)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<date_information>` [0..1]
- element `<has_date_type>` [1..1]
- element `<has_end>` [1..1]
- element `<has_beginning>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<date_information>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost date information (Additional information to the date in text form.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ ``.

#### Element `<has_date_type>`

Význam
  z obecnější třídy Time reference (A temporal interval or instant on which something relevant to the resource has happened.) → mající vlastnost has date type (Reference to the codelist of date types.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `date_type`.
Význam
  Date type (Type of a date in relation to the resource.)

#### Element `<has_end>`

Význam
  vlastnost has end (Time instant representing the end of a temporal interval.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_instant`.
Význam
  Time instant (A temporal entity with zero extent or duration.)

#### Element `<has_beginning>`

Význam
  vlastnost has beginning (Time instant representing the beginning of a temporal interval.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `time_instant`.
Význam
  Time instant (A temporal entity with zero extent or duration.)

## Specifikace struktury pro Checksum algorithm

Datová struktura pro Checksum algorithm. Algorithm used for Checksums.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Checksum algorithm, jež je definováno v souboru `../checksum-algorithm/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Nic není importováno.

#### Kořenové entity XSD schématu

- element `checksum_algorithm`
- komplexní typ `checksum_algorithm`

#### Kořenový element `<checksum_algorithm>`

Typ elementu
Obsah
  Obsahem elementu je typ `checksum_algorithm`.

#### Kořenový komplexní typ `checksum_algorithm`

Význam
  Checksum algorithm (Algorithm used for Checksums.)
Obsah - elementy v tomto pořadí

- element `<iri>` [1..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

## Specifikace struktury pro Description type

Datová struktura pro Description type. The type of the description.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Description type, jež je definováno v souboru `../description-type/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Nic není importováno.

#### Kořenové entity XSD schématu

- element `description_type`
- komplexní typ `description_type`

#### Kořenový element `<description_type>`

Typ elementu
Obsah
  Obsahem elementu je typ `description_type`.

#### Kořenový komplexní typ `description_type`

Význam
  Description type (The type of the description.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<label>` [0..*]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<label>`

Význam
  vlastnost label (Label of the description type.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..*
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

## Specifikace struktury pro Description

Datová struktura pro Description. All additional information that does not fit in any of the other categories. May be used for technical information or detailed information associated with a scientific instrument.

### Přehled XML struktury

Tato sekce popisuje XSD zachycující strukturu pro Description, jež je definováno v souboru `../description/schema.xsd`.

#### Importy

Seznam schémat, jež jsou tímto schématem importovány a použity.

Prefix | Namespace | Lokace schématu | Dokumentace
--- | --- | --- | ---
Stejný namespace jako hlavní dokument | ../description-type/schema.xsd |

#### Kořenové entity XSD schématu

- element `description`
- komplexní typ `description`

#### Kořenový element `<description>`

Typ elementu
Obsah
  Obsahem elementu je typ `description`.

#### Kořenový komplexní typ `description`

Význam
  Description (All additional information that does not fit in any of the other categories. May be used for technical information or detailed information associated with a scientific instrument.)
Obsah - elementy v tomto pořadí

- element `<iri>` [0..1]
- element `<description_text>` [1..1]
- element `<has_description_type>` [0..1]

#### Element `<iri>`

Význam
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:anyURI`.

#### Element `<description_text>`

Význam
  vlastnost description text (Text describing the resource.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  1..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `xs:string`.

#### Element `<has_description_type>`

Význam
  vlastnost has description type (Relation to the type of the description.)
Efektivní kardinalita elementu vůči nadřazeném elementu
  0..1
Nadřazený element
Typ elementu
Obsah
  Obsahem elementu je typ `description_type`.
Význam
  Description type (The type of the description.)

## Použité prefixy

Prefix | Namespace IRI
--- | ---
`dcterms` | `http://purl.org/dc/terms/`
`rdfs` | `http://www.w3.org/2000/01/rdf-schema#`
`rdf` | `http://www.w3.org/1999/02/22-rdf-syntax-ns#`
`locn` | `http://www.w3.org/ns/locn#`
`xsd` | `http://www.w3.org/2001/XMLSchema#`
`foaf` | `http://xmlns.com/foaf/0.1/`
`dcat` | `http://www.w3.org/ns/dcat#`
`skos` | `http://www.w3.org/2004/02/skos/core#`
`spdx` | `http://spdx.org/rdf/terms#`
`vcard` | `http://www.w3.org/2006/vcard/ns#`
`adms` | `http://www.w3.org/ns/adms#`
`prov` | `http://www.w3.org/ns/prov#`
`time` | `http://www.w3.org/2006/time#`

## Přílohy

Součástí této specifikace jsou následující přílohy.

Příloha | Odkaz
--- | ---
Aplikační profil | ./dsv.ttl
XML schéma | ../agent/schema.xsd
XML schéma | ../distribution/schema.xsd
XML schéma | ../contact-details/schema.xsd
XML schéma | ../resource/schema.xsd
XML schéma | ../location/schema.xsd
XML schéma | ../time_reference/schema.xsd
XML schéma | ../funding-reference/schema.xsd
XML schéma | ../terms-of-use/schema.xsd
XML schéma | ../resource-to-agent-relationship/schema.xsd
XML schéma | ../resource-agent-role-type/schema.xsd
XML schéma | ../application-profile/schema.xsd
XML schéma | ../media-type/schema.xsd
XML schéma | ../file/schema.xsd
XML schéma | ../validation-result/schema.xsd
XML schéma | ../subject-scheme/schema.xsd
XML schéma | ../address/schema.xsd
XML schéma | ../provenance-statement/schema.xsd
XML schéma | ../media-type/schema.xsd
XML schéma | ../subject/schema.xsd
XML schéma | ../metadata-record/schema.xsd
XML schéma | ../repository/schema.xsd
XML schéma | ../dataset/schema.xsd
XML schéma | ../identifier/schema.xsd
XML schéma | ../alternate-title/schema.xsd
XML schéma | ../geometry/schema.xsd
XML schéma | ../documentation/schema.xsd
XML schéma | ../data-service/schema.xsd
XML schéma | ../checksum/schema.xsd
XML schéma | ../organization/schema.xsd
XML schéma | ../license-document/schema.xsd
XML schéma | ../date-type/schema.xsd
XML schéma | ../resource-relation-type/schema.xsd
XML schéma | ../resource-type/schema.xsd
XML schéma | ../location-relation-type/schema.xsd
XML schéma | ../format/schema.xsd
XML schéma | ../alternate-title-type/schema.xsd
XML schéma | ../access-rights/schema.xsd
XML schéma | ../language-system/schema.xsd
XML schéma | ../identifier-scheme/schema.xsd
XML schéma | ../time-instant/schema.xsd
XML schéma | ../time-interval/schema.xsd
XML schéma | ../checksum-algorithm/schema.xsd
XML schéma | ../description-type/schema.xsd
XML schéma | ../description/schema.xsd
Dokumentace | #